# Auto-generated by scripts/scaffold_roots.py for Gana 1
from . import registry


@registry.register("1.1", root="भू", meaning="सत्तायाम्", gana="Bhvadi")
def root_1_1():
    """
    1.1 भू सत्तायाम् 
    """
    return "भू"


@registry.register("1.2", root="एध", meaning="वृद्धौ", gana="Bhvadi")
def root_1_2():
    """
    1.2 एध वृद्धौ 
    """
    return "एध"


@registry.register("1.3", root="स्पर्ध", meaning="सङ्घर्षे", gana="Bhvadi")
def root_1_3():
    """
    1.3 स्पर्ध सङ्घर्षे 
    """
    return "स्पर्ध"


@registry.register("1.4", root="गाधृ", meaning="प्रतिष्ठालिप्सयोर्ग्रन्थे च", gana="Bhvadi")
def root_1_4():
    """
    1.4 गाधृ प्रतिष्ठालिप्सयोर्ग्रन्थे च 
    """
    return "गाधृ"


@registry.register("1.5", root="बाधृ", meaning="लोडने विलोडने", gana="Bhvadi")
def root_1_5():
    """
    1.5 बाधृ लोडने विलोडने 
    """
    return "बाधृ"


@registry.register("1.7", root="नाथृ", meaning="याच्ञोपतापैश्वर्याशीष्षु", gana="Bhvadi")
def root_1_7():
    """
    1.7 नाथृ याच्ञोपतापैश्वर्याशीष्षु 
    """
    return "नाथृ"


@registry.register("1.8", root="दध", meaning="धारणे", gana="Bhvadi")
def root_1_8():
    """
    1.8 दध धारणे 
    """
    return "दध"


@registry.register("1.9", root="स्कुदि", meaning="आप्रवणे", gana="Bhvadi")
def root_1_9():
    """
    1.9 स्कुदि आप्रवणे 
    """
    return "स्कुदि"


@registry.register("1.10", root="श्विदि", meaning="श्वैत्ये", gana="Bhvadi")
def root_1_10():
    """
    1.10 श्विदि श्वैत्ये 
    """
    return "श्विदि"


@registry.register("1.11", root="वदि", meaning="अभिवादनस्तुत्योः", gana="Bhvadi")
def root_1_11():
    """
    1.11 वदि अभिवादनस्तुत्योः 
    """
    return "वदि"


@registry.register("1.12", root="भदि", meaning="कल्याणे सुखे च", gana="Bhvadi")
def root_1_12():
    """
    1.12 भदि कल्याणे सुखे च 
    """
    return "भदि"


@registry.register("1.13", root="मदि", meaning="स्तुतिमोदमदस्वप्नकान्तिगतिषु", gana="Bhvadi")
def root_1_13():
    """
    1.13 मदि स्तुतिमोदमदस्वप्नकान्तिगतिषु 
    """
    return "मदि"


@registry.register("1.14", root="स्पदि", meaning="किञ्चिच्चलने", gana="Bhvadi")
def root_1_14():
    """
    1.14 स्पदि किञ्चिच्चलने 
    """
    return "स्पदि"


@registry.register("1.15", root="क्लिदि", meaning="परिदेवने", gana="Bhvadi")
def root_1_15():
    """
    1.15 क्लिदि परिदेवने 
    """
    return "क्लिदि"


@registry.register("1.16", root="मुद", meaning="हर्षे", gana="Bhvadi")
def root_1_16():
    """
    1.16 मुद हर्षे 
    """
    return "मुद"


@registry.register("1.17", root="दद", meaning="दाने", gana="Bhvadi")
def root_1_17():
    """
    1.17 दद दाने 
    """
    return "दद"


@registry.register("1.19", root="स्वर्द", meaning="आस्वादने", gana="Bhvadi")
def root_1_19():
    """
    1.19 स्वर्द आस्वादने 
    """
    return "स्वर्द"


@registry.register("1.20", root="उर्द", meaning="माने क्रीडायां च", gana="Bhvadi")
def root_1_20():
    """
    1.20 उर्द माने क्रीडायां च 
    """
    return "उर्द"


@registry.register("1.23", root="गुर्दऽ", meaning="गुडक्रीडायामेव", gana="Bhvadi")
def root_1_23():
    """
    1.23 गुर्दऽ गुडक्रीडायामेव 
    """
    return "गुर्दऽ"


@registry.register("1.24", root="गुद", meaning="क्रीडायामेव", gana="Bhvadi")
def root_1_24():
    """
    1.24 गुद क्रीडायामेव 
    """
    return "गुद"


@registry.register("1.25", root="षूद", meaning="क्षरणे", gana="Bhvadi")
def root_1_25():
    """
    1.25 षूद क्षरणे 
    """
    return "षूद"


@registry.register("1.26", root="ह्राद", meaning="अव्यक्ते शब्दे", gana="Bhvadi")
def root_1_26():
    """
    1.26 ह्राद अव्यक्ते शब्दे 
    """
    return "ह्राद"


@registry.register("1.27", root="ह्लादी", meaning="सुखे च", gana="Bhvadi")
def root_1_27():
    """
    1.27 ह्लादी सुखे च 
    """
    return "ह्लादी"


@registry.register("1.28", root="स्वाद", meaning="आस्वादने", gana="Bhvadi")
def root_1_28():
    """
    1.28 स्वाद आस्वादने 
    """
    return "स्वाद"


@registry.register("1.29", root="पर्द", meaning="कुत्सिते शब्दे", gana="Bhvadi")
def root_1_29():
    """
    1.29 पर्द कुत्सिते शब्दे 
    """
    return "पर्द"


@registry.register("1.30", root="यती", meaning="प्रयत्ने", gana="Bhvadi")
def root_1_30():
    """
    1.30 यती प्रयत्ने 
    """
    return "यती"


@registry.register("1.32", root="जुतृ", meaning="भासने", gana="Bhvadi")
def root_1_32():
    """
    1.32 जुतृ भासने 
    """
    return "जुतृ"


@registry.register("1.34", root="वेथृ", meaning="याचने", gana="Bhvadi")
def root_1_34():
    """
    1.34 वेथृ याचने 
    """
    return "वेथृ"


@registry.register("1.35", root="श्रथि", meaning="शैथिल्ये", gana="Bhvadi")
def root_1_35():
    """
    1.35 श्रथि शैथिल्ये 
    """
    return "श्रथि"


@registry.register("1.36", root="ग्रथि", meaning="कौटिल्ये", gana="Bhvadi")
def root_1_36():
    """
    1.36 ग्रथि कौटिल्ये 
    """
    return "ग्रथि"


@registry.register("1.37", root="कत्थ", meaning="श्लाघायाम्", gana="Bhvadi")
def root_1_37():
    """
    1.37 कत्थ श्लाघायाम् 
    """
    return "कत्थ"


@registry.register("1.38", root="अत", meaning="सातत्यगमने", gana="Bhvadi")
def root_1_38():
    """
    1.38 अत सातत्यगमने 
    """
    return "अत"


@registry.register("1.39", root="चिती", meaning="सञ्ज्ञाने", gana="Bhvadi")
def root_1_39():
    """
    1.39 चिती सञ्ज्ञाने 
    """
    return "चिती"


@registry.register("1.40", root="च्युतिर्", meaning="आसेचने", gana="Bhvadi")
def root_1_40():
    """
    1.40 च्युतिर् आसेचने 
    """
    return "च्युतिर्"


@registry.register("1.41", root="श्चुतिर्", meaning="इत्येके", gana="Bhvadi")
def root_1_41():
    """
    1.41 श्चुतिर् इत्येके 
    """
    return "श्चुतिर्"


@registry.register("1.42", root="श्च्युतिर्", meaning="क्षरणे", gana="Bhvadi")
def root_1_42():
    """
    1.42 श्च्युतिर् क्षरणे 
    """
    return "श्च्युतिर्"


@registry.register("1.43", root="ज्युतिर्", meaning="भासने", gana="Bhvadi")
def root_1_43():
    """
    1.43 ज्युतिर् भासने 
    """
    return "ज्युतिर्"


@registry.register("1.44", root="मन्थ", meaning="विलोडने", gana="Bhvadi")
def root_1_44():
    """
    1.44 मन्थ विलोडने 
    """
    return "मन्थ"


@registry.register("1.48", root="मथि", meaning="हिंसासङ्क्लेशनयोः", gana="Bhvadi")
def root_1_48():
    """
    1.48 मथि हिंसासङ्क्लेशनयोः 
    """
    return "मथि"


@registry.register("1.49", root="षिध", meaning="गत्याम्", gana="Bhvadi")
def root_1_49():
    """
    1.49 षिध गत्याम् 
    """
    return "षिध"


@registry.register("1.50", root="षिधू", meaning="शास्त्रे माङ्गल्ये च", gana="Bhvadi")
def root_1_50():
    """
    1.50 षिधू शास्त्रे माङ्गल्ये च 
    """
    return "षिधू"


@registry.register("1.51", root="खादृ", meaning="भक्षणे", gana="Bhvadi")
def root_1_51():
    """
    1.51 खादृ भक्षणे 
    """
    return "खादृ"


@registry.register("1.52", root="खद", meaning="स्थैर्ये हिंसायां च", gana="Bhvadi")
def root_1_52():
    """
    1.52 खद स्थैर्ये हिंसायां च 
    """
    return "खद"


@registry.register("1.53", root="बद", meaning="स्थैर्ये", gana="Bhvadi")
def root_1_53():
    """
    1.53 बद स्थैर्ये 
    """
    return "बद"


@registry.register("1.54", root="गद", meaning="व्यक्तायां वाचि", gana="Bhvadi")
def root_1_54():
    """
    1.54 गद व्यक्तायां वाचि 
    """
    return "गद"


@registry.register("1.55", root="रद", meaning="विलेखने", gana="Bhvadi")
def root_1_55():
    """
    1.55 रद विलेखने 
    """
    return "रद"


@registry.register("1.56", root="णद", meaning="अव्यक्ते शब्दे", gana="Bhvadi")
def root_1_56():
    """
    1.56 णद अव्यक्ते शब्दे 
    """
    return "णद"


@registry.register("1.57", root="अर्द", meaning="गतौ याचने च", gana="Bhvadi")
def root_1_57():
    """
    1.57 अर्द गतौ याचने च 
    """
    return "अर्द"


@registry.register("1.59", root="गर्द", meaning="शब्दे", gana="Bhvadi")
def root_1_59():
    """
    1.59 गर्द शब्दे 
    """
    return "गर्द"


@registry.register("1.60", root="तर्द", meaning="हिंसायाम्", gana="Bhvadi")
def root_1_60():
    """
    1.60 तर्द हिंसायाम् 
    """
    return "तर्द"


@registry.register("1.61", root="कर्द", meaning="कुत्सिते शब्दे", gana="Bhvadi")
def root_1_61():
    """
    1.61 कर्द कुत्सिते शब्दे 
    """
    return "कर्द"


@registry.register("1.62", root="खर्द", meaning="दन्दशूके", gana="Bhvadi")
def root_1_62():
    """
    1.62 खर्द दन्दशूके 
    """
    return "खर्द"


@registry.register("1.64", root="अदि", meaning="बन्धने", gana="Bhvadi")
def root_1_64():
    """
    1.64 अदि बन्धने 
    """
    return "अदि"


@registry.register("1.65", root="इदि", meaning="परमैश्वर्ये", gana="Bhvadi")
def root_1_65():
    """
    1.65 इदि परमैश्वर्ये 
    """
    return "इदि"


@registry.register("1.66", root="बिदि", meaning="अवयवे", gana="Bhvadi")
def root_1_66():
    """
    1.66 बिदि अवयवे 
    """
    return "बिदि"


@registry.register("1.67", root="भिदि", meaning="इत्येके", gana="Bhvadi")
def root_1_67():
    """
    1.67 भिदि इत्येके 
    """
    return "भिदि"


@registry.register("1.68", root="गडि", meaning="वदनैकदेशे", gana="Bhvadi")
def root_1_68():
    """
    1.68 गडि वदनैकदेशे 
    """
    return "गडि"


@registry.register("1.69", root="णिदि", meaning="कुत्सायाम्", gana="Bhvadi")
def root_1_69():
    """
    1.69 णिदि कुत्सायाम् 
    """
    return "णिदि"


@registry.register("1.70", root="टुनदि", meaning="समृद्धौ", gana="Bhvadi")
def root_1_70():
    """
    1.70 टुनदि समृद्धौ 
    """
    return "टुनदि"


@registry.register("1.71", root="चदि", meaning="आह्लादे दीप्तौ च", gana="Bhvadi")
def root_1_71():
    """
    1.71 चदि आह्लादे दीप्तौ च 
    """
    return "चदि"


@registry.register("1.72", root="त्रदि", meaning="चेष्टायाम्", gana="Bhvadi")
def root_1_72():
    """
    1.72 त्रदि चेष्टायाम् 
    """
    return "त्रदि"


@registry.register("1.75", root="क्लदि", meaning="आह्वाने रोदने च", gana="Bhvadi")
def root_1_75():
    """
    1.75 क्लदि आह्वाने रोदने च 
    """
    return "क्लदि"


@registry.register("1.76", root="क्लिदि", meaning="परिदेवने", gana="Bhvadi")
def root_1_76():
    """
    1.76 क्लिदि परिदेवने 
    """
    return "क्लिदि"


@registry.register("1.77", root="शुन्ध", meaning="शुद्धौ", gana="Bhvadi")
def root_1_77():
    """
    1.77 शुन्ध शुद्धौ 
    """
    return "शुन्ध"


@registry.register("1.78", root="शीकृ", meaning="सेचने", gana="Bhvadi")
def root_1_78():
    """
    1.78 शीकृ सेचने 
    """
    return "शीकृ"


@registry.register("1.79", root="सीकृ", meaning="इत्येके", gana="Bhvadi")
def root_1_79():
    """
    1.79 सीकृ इत्येके 
    """
    return "सीकृ"


@registry.register("1.80", root="लोकृ", meaning="दर्शने", gana="Bhvadi")
def root_1_80():
    """
    1.80 लोकृ दर्शने 
    """
    return "लोकृ"


@registry.register("1.81", root="श्लोकृ", meaning="सङ्घाते", gana="Bhvadi")
def root_1_81():
    """
    1.81 श्लोकृ सङ्घाते 
    """
    return "श्लोकृ"


@registry.register("1.82", root="स्रोकृ", meaning="इति पाठान्तरम्", gana="Bhvadi")
def root_1_82():
    """
    1.82 स्रोकृ इति पाठान्तरम् 
    """
    return "स्रोकृ"


@registry.register("1.84", root="ध्रेकृ", meaning="शब्दोत्साहयोः", gana="Bhvadi")
def root_1_84():
    """
    1.84 ध्रेकृ शब्दोत्साहयोः 
    """
    return "ध्रेकृ"


@registry.register("1.85", root="रेकृ", meaning="शङ्कायाम्", gana="Bhvadi")
def root_1_85():
    """
    1.85 रेकृ शङ्कायाम् 
    """
    return "रेकृ"


@registry.register("1.90", root="श्लकि", meaning="गतौ गत्यर्थाः", gana="Bhvadi")
def root_1_90():
    """
    1.90 श्लकि गतौ गत्यर्थाः 
    """
    return "श्लकि"


@registry.register("1.91", root="शकि", meaning="शङ्कायाम्", gana="Bhvadi")
def root_1_91():
    """
    1.91 शकि शङ्कायाम् 
    """
    return "शकि"


@registry.register("1.92", root="अकि", meaning="लक्षणे", gana="Bhvadi")
def root_1_92():
    """
    1.92 अकि लक्षणे 
    """
    return "अकि"


@registry.register("1.93", root="वकि", meaning="कौटिल्ये", gana="Bhvadi")
def root_1_93():
    """
    1.93 वकि कौटिल्ये 
    """
    return "वकि"


@registry.register("1.94", root="मकि", meaning="मण्डने", gana="Bhvadi")
def root_1_94():
    """
    1.94 मकि मण्डने 
    """
    return "मकि"


@registry.register("1.95", root="कक", meaning="लौल्ये", gana="Bhvadi")
def root_1_95():
    """
    1.95 कक लौल्ये 
    """
    return "कक"


@registry.register("1.97", root="वृक", meaning="आदाने", gana="Bhvadi")
def root_1_97():
    """
    1.97 वृक आदाने 
    """
    return "वृक"


@registry.register("1.98", root="चक", meaning="तृप्तौ प्रतिघाते च", gana="Bhvadi")
def root_1_98():
    """
    1.98 चक तृप्तौ प्रतिघाते च 
    """
    return "चक"


@registry.register("1.105", root="ष्वस्कऽ", meaning="ष्वष्कऽ", gana="Bhvadi")
def root_1_105():
    """
    1.105 ष्वस्कऽ ष्वष्कऽ
    """
    return "ष्वस्कऽ"


@registry.register("1.106", root="वस्कऽ", meaning="वष्कऽ", gana="Bhvadi")
def root_1_106():
    """
    1.106 वस्कऽ वष्कऽ
    """
    return "वस्कऽ"


@registry.register("1.107", root="मस्कऽ", meaning="मष्क", gana="Bhvadi")
def root_1_107():
    """
    1.107 मस्कऽ मष्क
    """
    return "मस्कऽ"


@registry.register("1.113", root="लघि", meaning="गत्यर्थाः", gana="Bhvadi")
def root_1_113():
    """
    1.113 लघि गत्यर्थाः 
    """
    return "लघि"


@registry.register("1.114", root="ष्वकि", meaning="इत्येके तृतीयो दन्त्यादिरित्येके", gana="Bhvadi")
def root_1_114():
    """
    1.114 ष्वकि इत्येके तृतीयो दन्त्यादिरित्येके 
    """
    return "ष्वकि"


@registry.register("1.117", root="मघि", meaning="गत्याक्षेपे", gana="Bhvadi")
def root_1_117():
    """
    1.117 मघि गत्याक्षेपे 
    """
    return "मघि"


@registry.register("1.120", root="द्राघृ", meaning="सामर्थ्ये", gana="Bhvadi")
def root_1_120():
    """
    1.120 द्राघृ सामर्थ्ये 
    """
    return "द्राघृ"


@registry.register("1.121", root="ध्राघृ", meaning="इत्यपि केचित्", gana="Bhvadi")
def root_1_121():
    """
    1.121 ध्राघृ इत्यपि केचित् 
    """
    return "ध्राघृ"


@registry.register("1.122", root="श्लाघृ", meaning="कत्थने", gana="Bhvadi")
def root_1_122():
    """
    1.122 श्लाघृ कत्थने 
    """
    return "श्लाघृ"


@registry.register("1.123", root="फक्क", meaning="निचैर्गतौ", gana="Bhvadi")
def root_1_123():
    """
    1.123 फक्क निचैर्गतौ 
    """
    return "फक्क"


@registry.register("1.124", root="तक", meaning="हसने", gana="Bhvadi")
def root_1_124():
    """
    1.124 तक हसने 
    """
    return "तक"


@registry.register("1.125", root="तकि", meaning="कृच्छ्रजीवने", gana="Bhvadi")
def root_1_125():
    """
    1.125 तकि कृच्छ्रजीवने 
    """
    return "तकि"


@registry.register("1.126", root="बुक्क", meaning="भषणे", gana="Bhvadi")
def root_1_126():
    """
    1.126 बुक्क भषणे 
    """
    return "बुक्क"


@registry.register("1.127", root="शुक", meaning="गतौ", gana="Bhvadi")
def root_1_127():
    """
    1.127 शुक गतौ 
    """
    return "शुक"


@registry.register("1.128", root="कख", meaning="हसने", gana="Bhvadi")
def root_1_128():
    """
    1.128 कख हसने 
    """
    return "कख"


@registry.register("1.133", root="ध्राखृ", meaning="शोषणालमर्थयोः", gana="Bhvadi")
def root_1_133():
    """
    1.133 ध्राखृ शोषणालमर्थयोः 
    """
    return "ध्राखृ"


@registry.register("1.135", root="श्लाखृ", meaning="व्याप्तौ", gana="Bhvadi")
def root_1_135():
    """
    1.135 श्लाखृ व्याप्तौ 
    """
    return "श्लाखृ"


@registry.register("1.161", root="श्रगिऽ", meaning="श्वगिऽ ष्वगिऽ", gana="Bhvadi")
def root_1_161():
    """
    1.161 श्रगिऽ श्वगिऽ ष्वगिऽ
    """
    return "श्रगिऽ"


@registry.register("1.165", root="लिगि", meaning="गत्यर्थाः", gana="Bhvadi")
def root_1_165():
    """
    1.165 लिगि गत्यर्थाः 
    """
    return "लिगि"


@registry.register("1.174", root="शिखि", meaning="इत्यपि केचित्", gana="Bhvadi")
def root_1_174():
    """
    1.174 शिखि इत्यपि केचित् 
    """
    return "शिखि"


@registry.register("1.177", root="बुगि", meaning="वर्जने", gana="Bhvadi")
def root_1_177():
    """
    1.177 बुगि वर्जने 
    """
    return "बुगि"


@registry.register("1.178", root="वुगि", meaning="इत्येके", gana="Bhvadi")
def root_1_178():
    """
    1.178 वुगि इत्येके 
    """
    return "वुगि"


@registry.register("1.179", root="घघ", meaning="हसने", gana="Bhvadi")
def root_1_179():
    """
    1.179 घघ हसने 
    """
    return "घघ"


@registry.register("1.180", root="घग्घ", meaning="इत्येके", gana="Bhvadi")
def root_1_180():
    """
    1.180 घग्घ इत्येके 
    """
    return "घग्घ"


@registry.register("1.181", root="दघि", meaning="पालने", gana="Bhvadi")
def root_1_181():
    """
    1.181 दघि पालने 
    """
    return "दघि"


@registry.register("1.182", root="लघि", meaning="शोषणे भाषायां दीप्तौ सीमातिक्रमे च", gana="Bhvadi")
def root_1_182():
    """
    1.182 लघि शोषणे भाषायां दीप्तौ सीमातिक्रमे च 
    """
    return "लघि"


@registry.register("1.183", root="मघि", meaning="मण्डने", gana="Bhvadi")
def root_1_183():
    """
    1.183 मघि मण्डने 
    """
    return "मघि"


@registry.register("1.184", root="शिघि", meaning="आघ्राणे", gana="Bhvadi")
def root_1_184():
    """
    1.184 शिघि आघ्राणे 
    """
    return "शिघि"


@registry.register("1.185", root="अर्घ", meaning="मूल्ये", gana="Bhvadi")
def root_1_185():
    """
    1.185 अर्घ मूल्ये 
    """
    return "अर्घ"


@registry.register("1.186", root="वर्च", meaning="दीप्तौ", gana="Bhvadi")
def root_1_186():
    """
    1.186 वर्च दीप्तौ 
    """
    return "वर्च"


@registry.register("1.187", root="षच", meaning="सेचने सेवने च", gana="Bhvadi")
def root_1_187():
    """
    1.187 षच सेचने सेवने च 
    """
    return "षच"


@registry.register("1.188", root="लोचृ", meaning="दर्शने", gana="Bhvadi")
def root_1_188():
    """
    1.188 लोचृ दर्शने 
    """
    return "लोचृ"


@registry.register("1.189", root="शच", meaning="व्यक्तायां वाचि", gana="Bhvadi")
def root_1_189():
    """
    1.189 शच व्यक्तायां वाचि 
    """
    return "शच"


@registry.register("1.191", root="श्वचि", meaning="गतौ", gana="Bhvadi")
def root_1_191():
    """
    1.191 श्वचि गतौ 
    """
    return "श्वचि"


@registry.register("1.192", root="कच", meaning="बन्धने", gana="Bhvadi")
def root_1_192():
    """
    1.192 कच बन्धने 
    """
    return "कच"


@registry.register("1.194", root="काचि", meaning="दीप्तिबन्धनयोः", gana="Bhvadi")
def root_1_194():
    """
    1.194 काचि दीप्तिबन्धनयोः 
    """
    return "काचि"


@registry.register("1.196", root="मुचि", meaning="कल्कने", gana="Bhvadi")
def root_1_196():
    """
    1.196 मुचि कल्कने 
    """
    return "मुचि"


@registry.register("1.197", root="मचि", meaning="धारणोच्छ्रायपूजनेषु", gana="Bhvadi")
def root_1_197():
    """
    1.197 मचि धारणोच्छ्रायपूजनेषु 
    """
    return "मचि"


@registry.register("1.198", root="पचि", meaning="व्यक्तीकरणे", gana="Bhvadi")
def root_1_198():
    """
    1.198 पचि व्यक्तीकरणे 
    """
    return "पचि"


@registry.register("1.199", root="ष्टुच", meaning="प्रसादे", gana="Bhvadi")
def root_1_199():
    """
    1.199 ष्टुच प्रसादे 
    """
    return "ष्टुच"


@registry.register("1.200", root="ऋज", meaning="गतिस्थानार्जनोपार्जनेषु", gana="Bhvadi")
def root_1_200():
    """
    1.200 ऋज गतिस्थानार्जनोपार्जनेषु 
    """
    return "ऋज"


@registry.register("1.202", root="भृजी", meaning="भर्जने", gana="Bhvadi")
def root_1_202():
    """
    1.202 भृजी भर्जने 
    """
    return "भृजी"


@registry.register("1.205", root="भ्राजृ", meaning="दीप्तौ", gana="Bhvadi")
def root_1_205():
    """
    1.205 भ्राजृ दीप्तौ 
    """
    return "भ्राजृ"


@registry.register("1.206", root="रेजृ", meaning="दीप्तौ", gana="Bhvadi")
def root_1_206():
    """
    1.206 रेजृ दीप्तौ 
    """
    return "रेजृ"


@registry.register("1.207", root="ईज", meaning="गतिकुत्सनयोः", gana="Bhvadi")
def root_1_207():
    """
    1.207 ईज गतिकुत्सनयोः 
    """
    return "ईज"


@registry.register("1.208", root="ईजि", meaning="इत्येके", gana="Bhvadi")
def root_1_208():
    """
    1.208 ईजि इत्येके 
    """
    return "ईजि"


@registry.register("1.209", root="वीज", meaning="गतौ", gana="Bhvadi")
def root_1_209():
    """
    1.209 वीज गतौ 
    """
    return "वीज"


@registry.register("1.210", root="शुच", meaning="शोके", gana="Bhvadi")
def root_1_210():
    """
    1.210 शुच शोके 
    """
    return "शुच"


@registry.register("1.211", root="कुच", meaning="शब्दे तारे", gana="Bhvadi")
def root_1_211():
    """
    1.211 कुच शब्दे तारे 
    """
    return "कुच"


@registry.register("1.213", root="क्रुञ्च", meaning="कौटिल्याल्पीभावयोः", gana="Bhvadi")
def root_1_213():
    """
    1.213 क्रुञ्च कौटिल्याल्पीभावयोः 
    """
    return "क्रुञ्च"


@registry.register("1.214", root="लुञ्च", meaning="अपनयने", gana="Bhvadi")
def root_1_214():
    """
    1.214 लुञ्च अपनयने 
    """
    return "लुञ्च"


@registry.register("1.215", root="अञ्चु", meaning="गतिपूजनयोः", gana="Bhvadi")
def root_1_215():
    """
    1.215 अञ्चु गतिपूजनयोः 
    """
    return "अञ्चु"


@registry.register("1.223", root="म्लुचु", meaning="गत्यर्थाः", gana="Bhvadi")
def root_1_223():
    """
    1.223 म्लुचु गत्यर्थाः 
    """
    return "म्लुचु"


@registry.register("1.227", root="खुजु", meaning="स्तेयकरणे", gana="Bhvadi")
def root_1_227():
    """
    1.227 खुजु स्तेयकरणे 
    """
    return "खुजु"


@registry.register("1.229", root="षस्ज", meaning="षस्ज गतौ", gana="Bhvadi")
def root_1_229():
    """
    1.229 षस्ज षस्ज गतौ 
    """
    return "षस्ज"


@registry.register("1.231", root="गुजि", meaning="अव्यक्ते शब्दे", gana="Bhvadi")
def root_1_231():
    """
    1.231 गुजि अव्यक्ते शब्दे 
    """
    return "गुजि"


@registry.register("1.232", root="अर्च", meaning="पूजायाम्", gana="Bhvadi")
def root_1_232():
    """
    1.232 अर्च पूजायाम् 
    """
    return "अर्च"


@registry.register("1.233", root="म्लेच्छ", meaning="अव्यक्ते शब्दे", gana="Bhvadi")
def root_1_233():
    """
    1.233 म्लेच्छ अव्यक्ते शब्दे 
    """
    return "म्लेच्छ"


@registry.register("1.235", root="लाछि", meaning="लक्षणे", gana="Bhvadi")
def root_1_235():
    """
    1.235 लाछि लक्षणे 
    """
    return "लाछि"


@registry.register("1.236", root="वाछि", meaning="इच्छायाम्", gana="Bhvadi")
def root_1_236():
    """
    1.236 वाछि इच्छायाम् 
    """
    return "वाछि"


@registry.register("1.237", root="आछि", meaning="आयामे", gana="Bhvadi")
def root_1_237():
    """
    1.237 आछि आयामे 
    """
    return "आछि"


@registry.register("1.238", root="ह्रीछ", meaning="लज्जायाम्", gana="Bhvadi")
def root_1_238():
    """
    1.238 ह्रीछ लज्जायाम् 
    """
    return "ह्रीछ"


@registry.register("1.239", root="हुर्छा", meaning="कौटिल्ये", gana="Bhvadi")
def root_1_239():
    """
    1.239 हुर्छा कौटिल्ये 
    """
    return "हुर्छा"


@registry.register("1.240", root="मुर्छा", meaning="मोहसमुच्छ्राययोः", gana="Bhvadi")
def root_1_240():
    """
    1.240 मुर्छा मोहसमुच्छ्राययोः 
    """
    return "मुर्छा"


@registry.register("1.241", root="स्फुर्छा", meaning="विस्तृतौ", gana="Bhvadi")
def root_1_241():
    """
    1.241 स्फुर्छा विस्तृतौ 
    """
    return "स्फुर्छा"


@registry.register("1.242", root="युच्छ", meaning="प्रमादे", gana="Bhvadi")
def root_1_242():
    """
    1.242 युच्छ प्रमादे 
    """
    return "युच्छ"


@registry.register("1.243", root="उछि", meaning="उञ्छे", gana="Bhvadi")
def root_1_243():
    """
    1.243 उछि उञ्छे 
    """
    return "उछि"


@registry.register("1.244", root="उछी", meaning="विवासे", gana="Bhvadi")
def root_1_244():
    """
    1.244 उछी विवासे 
    """
    return "उछी"


@registry.register("1.252", root="ध्वजि", meaning="गतौ", gana="Bhvadi")
def root_1_252():
    """
    1.252 ध्वजि गतौ 
    """
    return "ध्वजि"


@registry.register("1.253", root="ध्रिज", meaning="च", gana="Bhvadi")
def root_1_253():
    """
    1.253 ध्रिज च 
    """
    return "ध्रिज"


@registry.register("1.255", root="कूजि", meaning="अव्यक्ते शब्दे", gana="Bhvadi")
def root_1_255():
    """
    1.255 कूजि अव्यक्ते शब्दे 
    """
    return "कूजि"


@registry.register("1.257", root="षर्ज", meaning="अर्जने", gana="Bhvadi")
def root_1_257():
    """
    1.257 षर्ज अर्जने 
    """
    return "षर्ज"


@registry.register("1.258", root="गर्ज", meaning="शब्दे", gana="Bhvadi")
def root_1_258():
    """
    1.258 गर्ज शब्दे 
    """
    return "गर्ज"


@registry.register("1.259", root="तर्ज", meaning="भर्त्सने", gana="Bhvadi")
def root_1_259():
    """
    1.259 तर्ज भर्त्सने 
    """
    return "तर्ज"


@registry.register("1.260", root="कर्ज", meaning="व्यथने", gana="Bhvadi")
def root_1_260():
    """
    1.260 कर्ज व्यथने 
    """
    return "कर्ज"


@registry.register("1.261", root="खर्ज", meaning="पूजने च", gana="Bhvadi")
def root_1_261():
    """
    1.261 खर्ज पूजने च 
    """
    return "खर्ज"


@registry.register("1.262", root="अज", meaning="गतिक्षेपणयोः", gana="Bhvadi")
def root_1_262():
    """
    1.262 अज गतिक्षेपणयोः 
    """
    return "अज"


@registry.register("1.263", root="तेज", meaning="पालने", gana="Bhvadi")
def root_1_263():
    """
    1.263 तेज पालने 
    """
    return "तेज"


@registry.register("1.264", root="खज", meaning="मन्थे", gana="Bhvadi")
def root_1_264():
    """
    1.264 खज मन्थे 
    """
    return "खज"


@registry.register("1.265", root="कज", meaning="मदे इत्येके", gana="Bhvadi")
def root_1_265():
    """
    1.265 कज मदे इत्येके 
    """
    return "कज"


@registry.register("1.266", root="खजि", meaning="गतिवैकल्ये", gana="Bhvadi")
def root_1_266():
    """
    1.266 खजि गतिवैकल्ये 
    """
    return "खजि"


@registry.register("1.267", root="एजृ", meaning="कम्पने", gana="Bhvadi")
def root_1_267():
    """
    1.267 एजृ कम्पने 
    """
    return "एजृ"


@registry.register("1.268", root="टुओस्फूर्जा", meaning="वज्रनिर्घोषे", gana="Bhvadi")
def root_1_268():
    """
    1.268 टुओस्फूर्जा वज्रनिर्घोषे 
    """
    return "टुओस्फूर्जा"


@registry.register("1.269", root="क्षि", meaning="क्षये", gana="Bhvadi")
def root_1_269():
    """
    1.269 क्षि क्षये 
    """
    return "क्षि"


@registry.register("1.270", root="क्षीज", meaning="अव्यक्ते शब्दे", gana="Bhvadi")
def root_1_270():
    """
    1.270 क्षीज अव्यक्ते शब्दे 
    """
    return "क्षीज"


@registry.register("1.272", root="लजि", meaning="भर्जने", gana="Bhvadi")
def root_1_272():
    """
    1.272 लजि भर्जने 
    """
    return "लजि"


@registry.register("1.274", root="लाजि", meaning="भर्त्सने च", gana="Bhvadi")
def root_1_274():
    """
    1.274 लाजि भर्त्सने च 
    """
    return "लाजि"


@registry.register("1.276", root="जजि", meaning="युद्धे", gana="Bhvadi")
def root_1_276():
    """
    1.276 जजि युद्धे 
    """
    return "जजि"


@registry.register("1.277", root="तुज", meaning="हिंसायाम्", gana="Bhvadi")
def root_1_277():
    """
    1.277 तुज हिंसायाम् 
    """
    return "तुज"


@registry.register("1.278", root="तुजि", meaning="पालने", gana="Bhvadi")
def root_1_278():
    """
    1.278 तुजि पालने 
    """
    return "तुजि"


@registry.register("1.284", root="मुजि", meaning="शब्दार्थाः", gana="Bhvadi")
def root_1_284():
    """
    1.284 मुजि शब्दार्थाः 
    """
    return "मुजि"


@registry.register("1.286", root="व्रज", meaning="गतौ", gana="Bhvadi")
def root_1_286():
    """
    1.286 व्रज गतौ 
    """
    return "व्रज"


@registry.register("1.287", root="अट्ट", meaning="अतिक्रमणहिंसनयोः अतिक्रमहिंसयोः", gana="Bhvadi")
def root_1_287():
    """
    1.287 अट्ट अतिक्रमणहिंसनयोः अतिक्रमहिंसयोः 
    """
    return "अट्ट"


@registry.register("1.288", root="वेष्ट", meaning="वेष्टने", gana="Bhvadi")
def root_1_288():
    """
    1.288 वेष्ट वेष्टने 
    """
    return "वेष्ट"


@registry.register("1.289", root="चेष्ट", meaning="चेष्टायाम्", gana="Bhvadi")
def root_1_289():
    """
    1.289 चेष्ट चेष्टायाम् 
    """
    return "चेष्ट"


@registry.register("1.291", root="लोष्ट", meaning="सङ्घाते", gana="Bhvadi")
def root_1_291():
    """
    1.291 लोष्ट सङ्घाते 
    """
    return "लोष्ट"


@registry.register("1.292", root="घट्ट", meaning="चलने", gana="Bhvadi")
def root_1_292():
    """
    1.292 घट्ट चलने 
    """
    return "घट्ट"


@registry.register("1.293", root="स्फुट", meaning="विकसने", gana="Bhvadi")
def root_1_293():
    """
    1.293 स्फुट विकसने 
    """
    return "स्फुट"


@registry.register("1.294", root="अठि", meaning="गतौ", gana="Bhvadi")
def root_1_294():
    """
    1.294 अठि गतौ 
    """
    return "अठि"


@registry.register("1.295", root="वठि", meaning="एकचर्यायाम्", gana="Bhvadi")
def root_1_295():
    """
    1.295 वठि एकचर्यायाम् 
    """
    return "वठि"


@registry.register("1.297", root="कठि", meaning="शोके", gana="Bhvadi")
def root_1_297():
    """
    1.297 कठि शोके 
    """
    return "कठि"


@registry.register("1.298", root="मुठि", meaning="पालने", gana="Bhvadi")
def root_1_298():
    """
    1.298 मुठि पालने 
    """
    return "मुठि"


@registry.register("1.299", root="हेठ", meaning="विबाधायाम्", gana="Bhvadi")
def root_1_299():
    """
    1.299 हेठ विबाधायाम् 
    """
    return "हेठ"


@registry.register("1.300", root="एठ", meaning="च", gana="Bhvadi")
def root_1_300():
    """
    1.300 एठ च 
    """
    return "एठ"


@registry.register("1.301", root="हिडि", meaning="गत्यनादरयोः", gana="Bhvadi")
def root_1_301():
    """
    1.301 हिडि गत्यनादरयोः 
    """
    return "हिडि"


@registry.register("1.302", root="हुडि", meaning="सङ्घाते", gana="Bhvadi")
def root_1_302():
    """
    1.302 हुडि सङ्घाते 
    """
    return "हुडि"


@registry.register("1.303", root="कुडि", meaning="दाहे", gana="Bhvadi")
def root_1_303():
    """
    1.303 कुडि दाहे 
    """
    return "कुडि"


@registry.register("1.304", root="वडि", meaning="विभाजने", gana="Bhvadi")
def root_1_304():
    """
    1.304 वडि विभाजने 
    """
    return "वडि"


@registry.register("1.305", root="मडि", meaning="च", gana="Bhvadi")
def root_1_305():
    """
    1.305 मडि च 
    """
    return "मडि"


@registry.register("1.306", root="भडि", meaning="परिभाषणे", gana="Bhvadi")
def root_1_306():
    """
    1.306 भडि परिभाषणे 
    """
    return "भडि"


@registry.register("1.307", root="पिडि", meaning="सङ्घाते", gana="Bhvadi")
def root_1_307():
    """
    1.307 पिडि सङ्घाते 
    """
    return "पिडि"


@registry.register("1.308", root="मुडि", meaning="मार्जने", gana="Bhvadi")
def root_1_308():
    """
    1.308 मुडि मार्जने 
    """
    return "मुडि"


@registry.register("1.309", root="तुडि", meaning="तोडने", gana="Bhvadi")
def root_1_309():
    """
    1.309 तुडि तोडने 
    """
    return "तुडि"


@registry.register("1.310", root="हुडि", meaning="वरणे", gana="Bhvadi")
def root_1_310():
    """
    1.310 हुडि वरणे 
    """
    return "हुडि"


@registry.register("1.311", root="स्फुडि", meaning="विकसने", gana="Bhvadi")
def root_1_311():
    """
    1.311 स्फुडि विकसने 
    """
    return "स्फुडि"


@registry.register("1.312", root="चडि", meaning="कोपे", gana="Bhvadi")
def root_1_312():
    """
    1.312 चडि कोपे 
    """
    return "चडि"


@registry.register("1.313", root="शडि", meaning="रुजायां सङ्घाते च", gana="Bhvadi")
def root_1_313():
    """
    1.313 शडि रुजायां सङ्घाते च 
    """
    return "शडि"


@registry.register("1.314", root="तडि", meaning="ताडने", gana="Bhvadi")
def root_1_314():
    """
    1.314 तडि ताडने 
    """
    return "तडि"


@registry.register("1.315", root="पडि", meaning="गतौ", gana="Bhvadi")
def root_1_315():
    """
    1.315 पडि गतौ 
    """
    return "पडि"


@registry.register("1.316", root="कडि", meaning="मदे", gana="Bhvadi")
def root_1_316():
    """
    1.316 कडि मदे 
    """
    return "कडि"


@registry.register("1.317", root="खडि", meaning="मन्थे", gana="Bhvadi")
def root_1_317():
    """
    1.317 खडि मन्थे 
    """
    return "खडि"


@registry.register("1.319", root="होडृ", meaning="अनादरे", gana="Bhvadi")
def root_1_319():
    """
    1.319 होडृ अनादरे 
    """
    return "होडृ"


@registry.register("1.320", root="बाडृ", meaning="आप्लाव्ये", gana="Bhvadi")
def root_1_320():
    """
    1.320 बाडृ आप्लाव्ये 
    """
    return "बाडृ"


@registry.register("1.321", root="वाडृ", meaning="इत्येके", gana="Bhvadi")
def root_1_321():
    """
    1.321 वाडृ इत्येके 
    """
    return "वाडृ"


@registry.register("1.323", root="ध्राडृ", meaning="विशरणे", gana="Bhvadi")
def root_1_323():
    """
    1.323 ध्राडृ विशरणे 
    """
    return "ध्राडृ"


@registry.register("1.324", root="शाडृ", meaning="श्लाघायाम्", gana="Bhvadi")
def root_1_324():
    """
    1.324 शाडृ श्लाघायाम् 
    """
    return "शाडृ"


@registry.register("1.325", root="शौटृ", meaning="गर्वे", gana="Bhvadi")
def root_1_325():
    """
    1.325 शौटृ गर्वे 
    """
    return "शौटृ"


@registry.register("1.326", root="यौटृ", meaning="बन्धे", gana="Bhvadi")
def root_1_326():
    """
    1.326 यौटृ बन्धे 
    """
    return "यौटृ"


@registry.register("1.328", root="म्रेडृ", meaning="उन्मादे", gana="Bhvadi")
def root_1_328():
    """
    1.328 म्रेडृ उन्मादे 
    """
    return "म्रेडृ"


@registry.register("1.329", root="म्लेटृ", meaning="इत्येके", gana="Bhvadi")
def root_1_329():
    """
    1.329 म्लेटृ इत्येके 
    """
    return "म्लेटृ"


@registry.register("1.330", root="कटे", meaning="वर्षावरणयोः", gana="Bhvadi")
def root_1_330():
    """
    1.330 कटे वर्षावरणयोः 
    """
    return "कटे"


@registry.register("1.331", root="चटे", meaning="इत्येके", gana="Bhvadi")
def root_1_331():
    """
    1.331 चटे इत्येके 
    """
    return "चटे"


@registry.register("1.333", root="पट", meaning="गतौ", gana="Bhvadi")
def root_1_333():
    """
    1.333 पट गतौ 
    """
    return "पट"


@registry.register("1.334", root="रट", meaning="परिभाषणे", gana="Bhvadi")
def root_1_334():
    """
    1.334 रट परिभाषणे 
    """
    return "रट"


@registry.register("1.335", root="लट", meaning="बाल्ये", gana="Bhvadi")
def root_1_335():
    """
    1.335 लट बाल्ये 
    """
    return "लट"


@registry.register("1.336", root="शट", meaning="रुजाविशरणगत्यवसादनेषु", gana="Bhvadi")
def root_1_336():
    """
    1.336 शट रुजाविशरणगत्यवसादनेषु 
    """
    return "शट"


@registry.register("1.337", root="वट", meaning="वेष्टने", gana="Bhvadi")
def root_1_337():
    """
    1.337 वट वेष्टने 
    """
    return "वट"


@registry.register("1.339", root="खिट", meaning="त्रासे", gana="Bhvadi")
def root_1_339():
    """
    1.339 खिट त्रासे 
    """
    return "खिट"


@registry.register("1.341", root="षिट", meaning="अनादरे", gana="Bhvadi")
def root_1_341():
    """
    1.341 षिट अनादरे 
    """
    return "षिट"


@registry.register("1.343", root="झट", meaning="सङ्घाते", gana="Bhvadi")
def root_1_343():
    """
    1.343 झट सङ्घाते 
    """
    return "झट"


@registry.register("1.344", root="भट", meaning="भृतौ", gana="Bhvadi")
def root_1_344():
    """
    1.344 भट भृतौ 
    """
    return "भट"


@registry.register("1.345", root="तट", meaning="उच्छ्राये", gana="Bhvadi")
def root_1_345():
    """
    1.345 तट उच्छ्राये 
    """
    return "तट"


@registry.register("1.346", root="खट", meaning="काङ्क्षायाम्", gana="Bhvadi")
def root_1_346():
    """
    1.346 खट काङ्क्षायाम् 
    """
    return "खट"


@registry.register("1.347", root="णट", meaning="नट नृत्तौ", gana="Bhvadi")
def root_1_347():
    """
    1.347 णट नट नृत्तौ 
    """
    return "णट"


@registry.register("1.348", root="पिट", meaning="शब्दसङ्घातयोः", gana="Bhvadi")
def root_1_348():
    """
    1.348 पिट शब्दसङ्घातयोः 
    """
    return "पिट"


@registry.register("1.349", root="हट", meaning="दीप्तौ च", gana="Bhvadi")
def root_1_349():
    """
    1.349 हट दीप्तौ च 
    """
    return "हट"


@registry.register("1.350", root="षट", meaning="अवयवे", gana="Bhvadi")
def root_1_350():
    """
    1.350 षट अवयवे 
    """
    return "षट"


@registry.register("1.351", root="लुट", meaning="विलोडने", gana="Bhvadi")
def root_1_351():
    """
    1.351 लुट विलोडने 
    """
    return "लुट"


@registry.register("1.352", root="लुड", meaning="इत्येके डान्तोऽयमित्येके", gana="Bhvadi")
def root_1_352():
    """
    1.352 लुड इत्येके डान्तोऽयमित्येके 
    """
    return "लुड"


@registry.register("1.353", root="चिट", meaning="परप्रैष्ये परप्रेष्ये", gana="Bhvadi")
def root_1_353():
    """
    1.353 चिट परप्रैष्ये परप्रेष्ये 
    """
    return "चिट"


@registry.register("1.354", root="विट", meaning="शब्दे", gana="Bhvadi")
def root_1_354():
    """
    1.354 विट शब्दे 
    """
    return "विट"


@registry.register("1.355", root="बिट", meaning="आक्रोशे", gana="Bhvadi")
def root_1_355():
    """
    1.355 बिट आक्रोशे 
    """
    return "बिट"


@registry.register("1.356", root="हिट", meaning="इत्येके", gana="Bhvadi")
def root_1_356():
    """
    1.356 हिट इत्येके 
    """
    return "हिट"


@registry.register("1.359", root="कटी", meaning="गतौ", gana="Bhvadi")
def root_1_359():
    """
    1.359 कटी गतौ 
    """
    return "कटी"


@registry.register("1.360", root="हेठ", meaning="विबाधायाम्", gana="Bhvadi")
def root_1_360():
    """
    1.360 हेठ विबाधायाम् 
    """
    return "हेठ"


@registry.register("1.361", root="मडि", meaning="भूषायाम्", gana="Bhvadi")
def root_1_361():
    """
    1.361 मडि भूषायाम् 
    """
    return "मडि"


@registry.register("1.362", root="कुडि", meaning="वैकल्ये", gana="Bhvadi")
def root_1_362():
    """
    1.362 कुडि वैकल्ये 
    """
    return "कुडि"


@registry.register("1.363", root="कुटि", meaning="इत्येके", gana="Bhvadi")
def root_1_363():
    """
    1.363 कुटि इत्येके 
    """
    return "कुटि"


@registry.register("1.365", root="प्रुड", meaning="मर्दने प्रमर्दने", gana="Bhvadi")
def root_1_365():
    """
    1.365 प्रुड मर्दने प्रमर्दने 
    """
    return "प्रुड"


@registry.register("1.367", root="पुट", meaning="इत्येके", gana="Bhvadi")
def root_1_367():
    """
    1.367 पुट इत्येके 
    """
    return "पुट"


@registry.register("1.368", root="चुडि", meaning="अल्पीभावे", gana="Bhvadi")
def root_1_368():
    """
    1.368 चुडि अल्पीभावे 
    """
    return "चुडि"


@registry.register("1.369", root="मुडि", meaning="खण्डने", gana="Bhvadi")
def root_1_369():
    """
    1.369 मुडि खण्डने 
    """
    return "मुडि"


@registry.register("1.370", root="पुडि", meaning="चेत्येके", gana="Bhvadi")
def root_1_370():
    """
    1.370 पुडि चेत्येके 
    """
    return "पुडि"


@registry.register("1.372", root="लुटि", meaning="स्तेये", gana="Bhvadi")
def root_1_372():
    """
    1.372 लुटि स्तेये 
    """
    return "लुटि"


@registry.register("1.374", root="लुठि", meaning="इत्येके", gana="Bhvadi")
def root_1_374():
    """
    1.374 लुठि इत्येके 
    """
    return "लुठि"


@registry.register("1.376", root="लुडि", meaning="इत्यपरे", gana="Bhvadi")
def root_1_376():
    """
    1.376 लुडि इत्यपरे 
    """
    return "लुडि"


@registry.register("1.377", root="वटि", meaning="विभाजने", gana="Bhvadi")
def root_1_377():
    """
    1.377 वटि विभाजने 
    """
    return "वटि"


@registry.register("1.378", root="बटि", meaning="इत्येके", gana="Bhvadi")
def root_1_378():
    """
    1.378 बटि इत्येके 
    """
    return "बटि"


@registry.register("1.379", root="स्फुटिर्", meaning="विशरणे", gana="Bhvadi")
def root_1_379():
    """
    1.379 स्फुटिर् विशरणे 
    """
    return "स्फुटिर्"


@registry.register("1.380", root="स्फुटि", meaning="इत्यपि केचित्", gana="Bhvadi")
def root_1_380():
    """
    1.380 स्फुटि इत्यपि केचित् 
    """
    return "स्फुटि"


@registry.register("1.381", root="पठ", meaning="व्यक्तायां वाचि", gana="Bhvadi")
def root_1_381():
    """
    1.381 पठ व्यक्तायां वाचि 
    """
    return "पठ"


@registry.register("1.382", root="वठ", meaning="स्थौल्ये", gana="Bhvadi")
def root_1_382():
    """
    1.382 वठ स्थौल्ये 
    """
    return "वठ"


@registry.register("1.383", root="बठ", meaning="इत्येके", gana="Bhvadi")
def root_1_383():
    """
    1.383 बठ इत्येके 
    """
    return "बठ"


@registry.register("1.384", root="मठ", meaning="मदनिवासयोः", gana="Bhvadi")
def root_1_384():
    """
    1.384 मठ मदनिवासयोः 
    """
    return "मठ"


@registry.register("1.385", root="कठ", meaning="कृच्छ्रजीवने", gana="Bhvadi")
def root_1_385():
    """
    1.385 कठ कृच्छ्रजीवने 
    """
    return "कठ"


@registry.register("1.386", root="रठ", meaning="परिभाषणे", gana="Bhvadi")
def root_1_386():
    """
    1.386 रठ परिभाषणे 
    """
    return "रठ"


@registry.register("1.387", root="रट", meaning="इत्येके ॥", gana="Bhvadi")
def root_1_387():
    """
    1.387 रट इत्येके ॥
    """
    return "रट"


@registry.register("1.388", root="हठ", meaning="प्लुतिशठत्वयोः", gana="Bhvadi")
def root_1_388():
    """
    1.388 हठ प्लुतिशठत्वयोः 
    """
    return "हठ"


@registry.register("1.391", root="ऊठ", meaning="उपघाते", gana="Bhvadi")
def root_1_391():
    """
    1.391 ऊठ उपघाते 
    """
    return "ऊठ"


@registry.register("1.392", root="उठ", meaning="इत्येके", gana="Bhvadi")
def root_1_392():
    """
    1.392 उठ इत्येके 
    """
    return "उठ"


@registry.register("1.393", root="पिठ", meaning="हिंसासङ्क्लेशनयोः", gana="Bhvadi")
def root_1_393():
    """
    1.393 पिठ हिंसासङ्क्लेशनयोः 
    """
    return "पिठ"


@registry.register("1.394", root="शठ", meaning="कैतवे च", gana="Bhvadi")
def root_1_394():
    """
    1.394 शठ कैतवे च 
    """
    return "शठ"


@registry.register("1.395", root="शुठ", meaning="गतिप्रतिघाते प्रतिघाते", gana="Bhvadi")
def root_1_395():
    """
    1.395 शुठ गतिप्रतिघाते प्रतिघाते 
    """
    return "शुठ"


@registry.register("1.396", root="शुठि", meaning="इत्येके", gana="Bhvadi")
def root_1_396():
    """
    1.396 शुठि इत्येके 
    """
    return "शुठि"


@registry.register("1.397", root="कुठि", meaning="च", gana="Bhvadi")
def root_1_397():
    """
    1.397 कुठि च 
    """
    return "कुठि"


@registry.register("1.398", root="लुठि", meaning="आलस्ये प्रतिघाते च", gana="Bhvadi")
def root_1_398():
    """
    1.398 लुठि आलस्ये प्रतिघाते च 
    """
    return "लुठि"


@registry.register("1.399", root="शुठि", meaning="शोषणे", gana="Bhvadi")
def root_1_399():
    """
    1.399 शुठि शोषणे 
    """
    return "शुठि"


@registry.register("1.401", root="लुठि", meaning="गतौ", gana="Bhvadi")
def root_1_401():
    """
    1.401 लुठि गतौ 
    """
    return "लुठि"


@registry.register("1.402", root="चुड्ड", meaning="चुद्ड भावकरणे", gana="Bhvadi")
def root_1_402():
    """
    1.402 चुड्ड चुद्ड भावकरणे 
    """
    return "चुड्ड"


@registry.register("1.403", root="अड्ड", meaning="अद्ड अभियोगे", gana="Bhvadi")
def root_1_403():
    """
    1.403 अड्ड अद्ड अभियोगे 
    """
    return "अड्ड"


@registry.register("1.404", root="कड्ड", meaning="कद्ड कार्कश्ये", gana="Bhvadi")
def root_1_404():
    """
    1.404 कड्ड कद्ड कार्कश्ये 
    """
    return "कड्ड"


@registry.register("1.405", root="क्रीडृ", meaning="विहारे", gana="Bhvadi")
def root_1_405():
    """
    1.405 क्रीडृ विहारे 
    """
    return "क्रीडृ"


@registry.register("1.406", root="तुडृ", meaning="तोडने", gana="Bhvadi")
def root_1_406():
    """
    1.406 तुडृ तोडने 
    """
    return "तुडृ"


@registry.register("1.407", root="तूडृ", meaning="इत्येके", gana="Bhvadi")
def root_1_407():
    """
    1.407 तूडृ इत्येके 
    """
    return "तूडृ"


@registry.register("1.410", root="होडृ", meaning="गतौ", gana="Bhvadi")
def root_1_410():
    """
    1.410 होडृ गतौ 
    """
    return "होडृ"


@registry.register("1.411", root="रौडृ", meaning="अनादरे", gana="Bhvadi")
def root_1_411():
    """
    1.411 रौडृ अनादरे 
    """
    return "रौडृ"


@registry.register("1.413", root="लोडृ", meaning="उन्मादे", gana="Bhvadi")
def root_1_413():
    """
    1.413 लोडृ उन्मादे 
    """
    return "लोडृ"


@registry.register("1.414", root="अड", meaning="उद्यमे", gana="Bhvadi")
def root_1_414():
    """
    1.414 अड उद्यमे 
    """
    return "अड"


@registry.register("1.415", root="लड", meaning="विलासे", gana="Bhvadi")
def root_1_415():
    """
    1.415 लड विलासे 
    """
    return "लड"


@registry.register("1.416", root="लल", meaning="इत्येके ईप्सायाम्", gana="Bhvadi")
def root_1_416():
    """
    1.416 लल इत्येके ईप्सायाम् 
    """
    return "लल"


@registry.register("1.417", root="कड", meaning="मदे", gana="Bhvadi")
def root_1_417():
    """
    1.417 कड मदे 
    """
    return "कड"


@registry.register("1.418", root="कडि", meaning="इत्येके ॥", gana="Bhvadi")
def root_1_418():
    """
    1.418 कडि इत्येके ॥
    """
    return "कडि"


@registry.register("1.419", root="गडि", meaning="वदनैकदेशे", gana="Bhvadi")
def root_1_419():
    """
    1.419 गडि वदनैकदेशे 
    """
    return "गडि"


@registry.register("1.423", root="ष्टेपृ", meaning="क्षरणार्थाः", gana="Bhvadi")
def root_1_423():
    """
    1.423 ष्टेपृ क्षरणार्थाः 
    """
    return "ष्टेपृ"


@registry.register("1.424", root="ग्लेपृ", meaning="दैन्ये", gana="Bhvadi")
def root_1_424():
    """
    1.424 ग्लेपृ दैन्ये 
    """
    return "ग्लेपृ"


@registry.register("1.425", root="टुवेपृ", meaning="कम्पने", gana="Bhvadi")
def root_1_425():
    """
    1.425 टुवेपृ कम्पने 
    """
    return "टुवेपृ"


@registry.register("1.428", root="ग्लेपृ", meaning="च", gana="Bhvadi")
def root_1_428():
    """
    1.428 ग्लेपृ च 
    """
    return "ग्लेपृ"


@registry.register("1.431", root="लेपृ", meaning="गतौ", gana="Bhvadi")
def root_1_431():
    """
    1.431 लेपृ गतौ 
    """
    return "लेपृ"


@registry.register("1.433", root="धेपृ", meaning="च", gana="Bhvadi")
def root_1_433():
    """
    1.433 धेपृ च 
    """
    return "धेपृ"


@registry.register("1.434", root="त्रपूष्", meaning="लज्जायाम्", gana="Bhvadi")
def root_1_434():
    """
    1.434 त्रपूष् लज्जायाम् 
    """
    return "त्रपूष्"


@registry.register("1.435", root="कपि", meaning="चलने", gana="Bhvadi")
def root_1_435():
    """
    1.435 कपि चलने 
    """
    return "कपि"


@registry.register("1.438", root="अबि", meaning="शब्दे", gana="Bhvadi")
def root_1_438():
    """
    1.438 अबि शब्दे 
    """
    return "अबि"


@registry.register("1.439", root="लबि", meaning="अवस्रंसने च", gana="Bhvadi")
def root_1_439():
    """
    1.439 लबि अवस्रंसने च 
    """
    return "लबि"


@registry.register("1.440", root="कबृ", meaning="वर्णे", gana="Bhvadi")
def root_1_440():
    """
    1.440 कबृ वर्णे 
    """
    return "कबृ"


@registry.register("1.441", root="क्लीबृ", meaning="अधार्ष्ट्ये", gana="Bhvadi")
def root_1_441():
    """
    1.441 क्लीबृ अधार्ष्ट्ये 
    """
    return "क्लीबृ"


@registry.register("1.442", root="क्षीबृ", meaning="मदे", gana="Bhvadi")
def root_1_442():
    """
    1.442 क्षीबृ मदे 
    """
    return "क्षीबृ"


@registry.register("1.443", root="क्षीवृ", meaning="इत्येके", gana="Bhvadi")
def root_1_443():
    """
    1.443 क्षीवृ इत्येके 
    """
    return "क्षीवृ"


@registry.register("1.444", root="शीभृ", meaning="कत्थने", gana="Bhvadi")
def root_1_444():
    """
    1.444 शीभृ कत्थने 
    """
    return "शीभृ"


@registry.register("1.446", root="चीभृ", meaning="च", gana="Bhvadi")
def root_1_446():
    """
    1.446 चीभृ च 
    """
    return "चीभृ"


@registry.register("1.447", root="रेभृ", meaning="शब्दे", gana="Bhvadi")
def root_1_447():
    """
    1.447 रेभृ शब्दे 
    """
    return "रेभृ"


@registry.register("1.449", root="रभि", meaning="क्वचित्पठ्येते इत्येके", gana="Bhvadi")
def root_1_449():
    """
    1.449 रभि क्वचित्पठ्येते इत्येके 
    """
    return "रभि"


@registry.register("1.450", root="लभि", meaning="च", gana="Bhvadi")
def root_1_450():
    """
    1.450 लभि च 
    """
    return "लभि"


@registry.register("1.452", root="स्कभि", meaning="प्रतिबन्धे", gana="Bhvadi")
def root_1_452():
    """
    1.452 स्कभि प्रतिबन्धे 
    """
    return "स्कभि"


@registry.register("1.454", root="जृभि", meaning="गात्रविनामे", gana="Bhvadi")
def root_1_454():
    """
    1.454 जृभि गात्रविनामे 
    """
    return "जृभि"


@registry.register("1.455", root="शल्भ", meaning="कत्थने", gana="Bhvadi")
def root_1_455():
    """
    1.455 शल्भ कत्थने 
    """
    return "शल्भ"


@registry.register("1.456", root="वल्भ", meaning="भोजने", gana="Bhvadi")
def root_1_456():
    """
    1.456 वल्भ भोजने 
    """
    return "वल्भ"


@registry.register("1.457", root="गल्भ", meaning="धार्ष्ट्ये", gana="Bhvadi")
def root_1_457():
    """
    1.457 गल्भ धार्ष्ट्ये 
    """
    return "गल्भ"


@registry.register("1.458", root="श्रम्भु", meaning="प्रमादे", gana="Bhvadi")
def root_1_458():
    """
    1.458 श्रम्भु प्रमादे 
    """
    return "श्रम्भु"


@registry.register("1.459", root="स्रम्भु", meaning="इत्येके दन्त्यादिश्च", gana="Bhvadi")
def root_1_459():
    """
    1.459 स्रम्भु इत्येके दन्त्यादिश्च 
    """
    return "स्रम्भु"


@registry.register("1.460", root="ष्टुभु", meaning="स्तम्भे", gana="Bhvadi")
def root_1_460():
    """
    1.460 ष्टुभु स्तम्भे 
    """
    return "ष्टुभु"


@registry.register("1.461", root="गुपू", meaning="रक्षणे", gana="Bhvadi")
def root_1_461():
    """
    1.461 गुपू रक्षणे 
    """
    return "गुपू"


@registry.register("1.462", root="धूप", meaning="सन्तापे", gana="Bhvadi")
def root_1_462():
    """
    1.462 धूप सन्तापे 
    """
    return "धूप"


@registry.register("1.464", root="जल्प", meaning="व्यक्तायां वाचि", gana="Bhvadi")
def root_1_464():
    """
    1.464 जल्प व्यक्तायां वाचि 
    """
    return "जल्प"


@registry.register("1.465", root="चप", meaning="सान्त्वने", gana="Bhvadi")
def root_1_465():
    """
    1.465 चप सान्त्वने 
    """
    return "चप"


@registry.register("1.466", root="षप", meaning="समवाये", gana="Bhvadi")
def root_1_466():
    """
    1.466 षप समवाये 
    """
    return "षप"


@registry.register("1.468", root="लप", meaning="व्यक्तायां वाचि", gana="Bhvadi")
def root_1_468():
    """
    1.468 लप व्यक्तायां वाचि 
    """
    return "लप"


@registry.register("1.469", root="चुप", meaning="मन्दायां गतौ", gana="Bhvadi")
def root_1_469():
    """
    1.469 चुप मन्दायां गतौ 
    """
    return "चुप"


@registry.register("1.477", root="त्रुम्फ", meaning="हिंसार्थाः", gana="Bhvadi")
def root_1_477():
    """
    1.477 त्रुम्फ हिंसार्थाः 
    """
    return "त्रुम्फ"


@registry.register("1.491", root="चर्ब", meaning="गतौ", gana="Bhvadi")
def root_1_491():
    """
    1.491 चर्ब गतौ 
    """
    return "चर्ब"


@registry.register("1.492", root="कुबि", meaning="आच्छादने छादने", gana="Bhvadi")
def root_1_492():
    """
    1.492 कुबि आच्छादने छादने 
    """
    return "कुबि"


@registry.register("1.494", root="तुबि", meaning="अर्दने", gana="Bhvadi")
def root_1_494():
    """
    1.494 तुबि अर्दने 
    """
    return "तुबि"


@registry.register("1.495", root="चुबि", meaning="वक्त्रसंयोगे", gana="Bhvadi")
def root_1_495():
    """
    1.495 चुबि वक्त्रसंयोगे 
    """
    return "चुबि"


@registry.register("1.497", root="षृम्भु", meaning="हिंसार्थौ", gana="Bhvadi")
def root_1_497():
    """
    1.497 षृम्भु हिंसार्थौ 
    """
    return "षृम्भु"


@registry.register("1.499", root="षिम्भु", meaning="इत्येके", gana="Bhvadi")
def root_1_499():
    """
    1.499 षिम्भु इत्येके 
    """
    return "षिम्भु"


@registry.register("1.501", root="शुम्भ", meaning="भाषने", gana="Bhvadi")
def root_1_501():
    """
    1.501 शुम्भ भाषने 
    """
    return "शुम्भ"


@registry.register("1.504", root="घृणि", meaning="ग्रहणे", gana="Bhvadi")
def root_1_504():
    """
    1.504 घृणि ग्रहणे 
    """
    return "घृणि"


@registry.register("1.506", root="घूर्ण", meaning="भ्रमणे", gana="Bhvadi")
def root_1_506():
    """
    1.506 घूर्ण भ्रमणे 
    """
    return "घूर्ण"


@registry.register("1.507", root="पण", meaning="व्यवहारे स्तुतौ च", gana="Bhvadi")
def root_1_507():
    """
    1.507 पण व्यवहारे स्तुतौ च 
    """
    return "पण"


@registry.register("1.508", root="पन", meaning="च", gana="Bhvadi")
def root_1_508():
    """
    1.508 पन च 
    """
    return "पन"


@registry.register("1.509", root="भाम", meaning="क्रोधे", gana="Bhvadi")
def root_1_509():
    """
    1.509 भाम क्रोधे 
    """
    return "भाम"


@registry.register("1.510", root="क्षमूष्", meaning="सहने", gana="Bhvadi")
def root_1_510():
    """
    1.510 क्षमूष् सहने 
    """
    return "क्षमूष्"


@registry.register("1.511", root="कमु", meaning="कान्तौ", gana="Bhvadi")
def root_1_511():
    """
    1.511 कमु कान्तौ 
    """
    return "कमु"


@registry.register("1.519", root="व्रणऽ", meaning="ब्रणऽ", gana="Bhvadi")
def root_1_519():
    """
    1.519 व्रणऽ ब्रणऽ
    """
    return "व्रणऽ"


@registry.register("1.521", root="ध्वण", meaning="शब्दार्थाः", gana="Bhvadi")
def root_1_521():
    """
    1.521 ध्वण शब्दार्थाः 
    """
    return "ध्वण"


@registry.register("1.522", root="धण", meaning="इत्यपि केचित्", gana="Bhvadi")
def root_1_522():
    """
    1.522 धण इत्यपि केचित् 
    """
    return "धण"


@registry.register("1.523", root="ओणृ", meaning="अपनयने", gana="Bhvadi")
def root_1_523():
    """
    1.523 ओणृ अपनयने 
    """
    return "ओणृ"


@registry.register("1.524", root="शोणृ", meaning="वर्णगत्योः", gana="Bhvadi")
def root_1_524():
    """
    1.524 शोणृ वर्णगत्योः 
    """
    return "शोणृ"


@registry.register("1.525", root="श्रोणृ", meaning="सङ्घाते", gana="Bhvadi")
def root_1_525():
    """
    1.525 श्रोणृ सङ्घाते 
    """
    return "श्रोणृ"


@registry.register("1.526", root="श्लोणृ", meaning="च", gana="Bhvadi")
def root_1_526():
    """
    1.526 श्लोणृ च 
    """
    return "श्लोणृ"


@registry.register("1.527", root="पैणृ", meaning="गतिप्रेरणश्लेषणेषु", gana="Bhvadi")
def root_1_527():
    """
    1.527 पैणृ गतिप्रेरणश्लेषणेषु 
    """
    return "पैणृ"


@registry.register("1.528", root="प्रैणृ", meaning="इत्यपि ॥", gana="Bhvadi")
def root_1_528():
    """
    1.528 प्रैणृ इत्यपि ॥
    """
    return "प्रैणृ"


@registry.register("1.529", root="ध्रणऽ", meaning="शब्दे", gana="Bhvadi")
def root_1_529():
    """
    1.529 ध्रणऽ शब्दे 
    """
    return "ध्रणऽ"


@registry.register("1.530", root="बण", meaning="इत्यपि केचित्", gana="Bhvadi")
def root_1_530():
    """
    1.530 बण इत्यपि केचित् 
    """
    return "बण"


@registry.register("1.531", root="कनी", meaning="दीप्तिकान्तिगतिषु", gana="Bhvadi")
def root_1_531():
    """
    1.531 कनी दीप्तिकान्तिगतिषु 
    """
    return "कनी"


@registry.register("1.533", root="वन", meaning="शब्दे", gana="Bhvadi")
def root_1_533():
    """
    1.533 वन शब्दे 
    """
    return "वन"


@registry.register("1.535", root="षण", meaning="सम्भक्तौ", gana="Bhvadi")
def root_1_535():
    """
    1.535 षण सम्भक्तौ 
    """
    return "षण"


@registry.register("1.536", root="अम", meaning="गत्यादिषु गतौ शब्दे सम्भक्तौ च", gana="Bhvadi")
def root_1_536():
    """
    1.536 अम गत्यादिषु गतौ शब्दे सम्भक्तौ च 
    """
    return "अम"


@registry.register("1.539", root="मीमृ", meaning="गतौ", gana="Bhvadi")
def root_1_539():
    """
    1.539 मीमृ गतौ 
    """
    return "मीमृ"


@registry.register("1.543", root="झमु", meaning="अदने", gana="Bhvadi")
def root_1_543():
    """
    1.543 झमु अदने 
    """
    return "झमु"


@registry.register("1.544", root="जिमु", meaning="इति केचित्", gana="Bhvadi")
def root_1_544():
    """
    1.544 जिमु इति केचित् 
    """
    return "जिमु"


@registry.register("1.545", root="क्रमु", meaning="पादविक्षेपे", gana="Bhvadi")
def root_1_545():
    """
    1.545 क्रमु पादविक्षेपे 
    """
    return "क्रमु"


@registry.register("1.552", root="णय", meaning="गतौ", gana="Bhvadi")
def root_1_552():
    """
    1.552 णय गतौ 
    """
    return "णय"


@registry.register("1.553", root="दय", meaning="दानगतिरक्षणहिंसादानेषु", gana="Bhvadi")
def root_1_553():
    """
    1.553 दय दानगतिरक्षणहिंसादानेषु 
    """
    return "दय"


@registry.register("1.554", root="रय", meaning="गतौ", gana="Bhvadi")
def root_1_554():
    """
    1.554 रय गतौ 
    """
    return "रय"


@registry.register("1.555", root="लय", meaning="च", gana="Bhvadi")
def root_1_555():
    """
    1.555 लय च 
    """
    return "लय"


@registry.register("1.556", root="ऊयी", meaning="तन्तुसन्ताने", gana="Bhvadi")
def root_1_556():
    """
    1.556 ऊयी तन्तुसन्ताने 
    """
    return "ऊयी"


@registry.register("1.557", root="पूयी", meaning="विशरणे दुर्गन्धे च", gana="Bhvadi")
def root_1_557():
    """
    1.557 पूयी विशरणे दुर्गन्धे च 
    """
    return "पूयी"


@registry.register("1.558", root="क्नूयी", meaning="शब्दे उन्दे च", gana="Bhvadi")
def root_1_558():
    """
    1.558 क्नूयी शब्दे उन्दे च 
    """
    return "क्नूयी"


@registry.register("1.559", root="क्ष्मायी", meaning="विधूनने", gana="Bhvadi")
def root_1_559():
    """
    1.559 क्ष्मायी विधूनने 
    """
    return "क्ष्मायी"


@registry.register("1.561", root="ओप्यायी", meaning="वृद्धौ", gana="Bhvadi")
def root_1_561():
    """
    1.561 ओप्यायी वृद्धौ 
    """
    return "ओप्यायी"


@registry.register("1.562", root="तायृ", meaning="सन्तानपालनयोः", gana="Bhvadi")
def root_1_562():
    """
    1.562 तायृ सन्तानपालनयोः 
    """
    return "तायृ"


@registry.register("1.563", root="शल", meaning="चलनसंवरणयोः", gana="Bhvadi")
def root_1_563():
    """
    1.563 शल चलनसंवरणयोः 
    """
    return "शल"


@registry.register("1.565", root="वल्ल", meaning="संवरणे सञ्चलने च", gana="Bhvadi")
def root_1_565():
    """
    1.565 वल्ल संवरणे सञ्चलने च 
    """
    return "वल्ल"


@registry.register("1.567", root="मल्ल", meaning="धारणे", gana="Bhvadi")
def root_1_567():
    """
    1.567 मल्ल धारणे 
    """
    return "मल्ल"


@registry.register("1.569", root="भल्ल", meaning="परिभाषणहिंसादानेषु", gana="Bhvadi")
def root_1_569():
    """
    1.569 भल्ल परिभाषणहिंसादानेषु 
    """
    return "भल्ल"


@registry.register("1.570", root="कल", meaning="शब्दसङ्ख्यानयोः", gana="Bhvadi")
def root_1_570():
    """
    1.570 कल शब्दसङ्ख्यानयोः 
    """
    return "कल"


@registry.register("1.571", root="कल्ल", meaning="अव्यक्ते शब्दे", gana="Bhvadi")
def root_1_571():
    """
    1.571 कल्ल अव्यक्ते शब्दे 
    """
    return "कल्ल"


@registry.register("1.573", root="देवृ", meaning="देवने", gana="Bhvadi")
def root_1_573():
    """
    1.573 देवृ देवने 
    """
    return "देवृ"


@registry.register("1.579", root="म्लेवृ", meaning="सेवने", gana="Bhvadi")
def root_1_579():
    """
    1.579 म्लेवृ सेवने 
    """
    return "म्लेवृ"


@registry.register("1.583", root="केवृ", meaning="इत्यप्येके", gana="Bhvadi")
def root_1_583():
    """
    1.583 केवृ इत्यप्येके 
    """
    return "केवृ"


@registry.register("1.584", root="रेवृ", meaning="प्लवगतौ", gana="Bhvadi")
def root_1_584():
    """
    1.584 रेवृ प्लवगतौ 
    """
    return "रेवृ"


@registry.register("1.585", root="मव्य", meaning="बन्धने", gana="Bhvadi")
def root_1_585():
    """
    1.585 मव्य बन्धने 
    """
    return "मव्य"


@registry.register("1.586", root="षूर्क्ष्यऽ", meaning="सूर्क्ष्यऽ", gana="Bhvadi")
def root_1_586():
    """
    1.586 षूर्क्ष्यऽ सूर्क्ष्यऽ
    """
    return "षूर्क्ष्यऽ"


@registry.register("1.588", root="ईर्ष्य", meaning="ईर्ष्यार्थाः", gana="Bhvadi")
def root_1_588():
    """
    1.588 ईर्ष्य ईर्ष्यार्थाः 
    """
    return "ईर्ष्य"


@registry.register("1.589", root="हय", meaning="गतौ", gana="Bhvadi")
def root_1_589():
    """
    1.589 हय गतौ 
    """
    return "हय"


@registry.register("1.590", root="शुच्य", meaning="अभिषवे", gana="Bhvadi")
def root_1_590():
    """
    1.590 शुच्य अभिषवे 
    """
    return "शुच्य"


@registry.register("1.591", root="चुच्य", meaning="इत्येके", gana="Bhvadi")
def root_1_591():
    """
    1.591 चुच्य इत्येके 
    """
    return "चुच्य"


@registry.register("1.592", root="हर्य", meaning="गतिकान्त्योः", gana="Bhvadi")
def root_1_592():
    """
    1.592 हर्य गतिकान्त्योः 
    """
    return "हर्य"


@registry.register("1.593", root="अल", meaning="अल भूषणपर्याप्तिवारणेषु", gana="Bhvadi")
def root_1_593():
    """
    1.593 अल अल भूषणपर्याप्तिवारणेषु 
    """
    return "अल"


@registry.register("1.594", root="ञिफला", meaning="विशरणे", gana="Bhvadi")
def root_1_594():
    """
    1.594 ञिफला विशरणे 
    """
    return "ञिफला"


@registry.register("1.598", root="क्ष्मील", meaning="निमेषणे", gana="Bhvadi")
def root_1_598():
    """
    1.598 क्ष्मील निमेषणे 
    """
    return "क्ष्मील"


@registry.register("1.599", root="पील", meaning="प्रतिष्टम्भे", gana="Bhvadi")
def root_1_599():
    """
    1.599 पील प्रतिष्टम्भे 
    """
    return "पील"


@registry.register("1.600", root="णील", meaning="वर्णे", gana="Bhvadi")
def root_1_600():
    """
    1.600 णील वर्णे 
    """
    return "णील"


@registry.register("1.601", root="शील", meaning="समाधौ", gana="Bhvadi")
def root_1_601():
    """
    1.601 शील समाधौ 
    """
    return "शील"


@registry.register("1.602", root="कील", meaning="बन्धने", gana="Bhvadi")
def root_1_602():
    """
    1.602 कील बन्धने 
    """
    return "कील"


@registry.register("1.603", root="कूल", meaning="आवरणे", gana="Bhvadi")
def root_1_603():
    """
    1.603 कूल आवरणे 
    """
    return "कूल"


@registry.register("1.604", root="शूल", meaning="रुजायां सङ्घाते च", gana="Bhvadi")
def root_1_604():
    """
    1.604 शूल रुजायां सङ्घाते च 
    """
    return "शूल"


@registry.register("1.605", root="तूल", meaning="निष्कर्षे", gana="Bhvadi")
def root_1_605():
    """
    1.605 तूल निष्कर्षे 
    """
    return "तूल"


@registry.register("1.606", root="पूल", meaning="सङ्घाते", gana="Bhvadi")
def root_1_606():
    """
    1.606 पूल सङ्घाते 
    """
    return "पूल"


@registry.register("1.607", root="मूल", meaning="प्रतिष्ठायाम्", gana="Bhvadi")
def root_1_607():
    """
    1.607 मूल प्रतिष्ठायाम् 
    """
    return "मूल"


@registry.register("1.608", root="फल", meaning="निष्पत्तौ", gana="Bhvadi")
def root_1_608():
    """
    1.608 फल निष्पत्तौ 
    """
    return "फल"


@registry.register("1.609", root="चुल्ल", meaning="भावकरणे", gana="Bhvadi")
def root_1_609():
    """
    1.609 चुल्ल भावकरणे 
    """
    return "चुल्ल"


@registry.register("1.610", root="फुल्ल", meaning="विकसने", gana="Bhvadi")
def root_1_610():
    """
    1.610 फुल्ल विकसने 
    """
    return "फुल्ल"


@registry.register("1.611", root="चिल्ल", meaning="शैथिल्ये भावकरणे च", gana="Bhvadi")
def root_1_611():
    """
    1.611 चिल्ल शैथिल्ये भावकरणे च 
    """
    return "चिल्ल"


@registry.register("1.612", root="तिल", meaning="गतौ", gana="Bhvadi")
def root_1_612():
    """
    1.612 तिल गतौ 
    """
    return "तिल"


@registry.register("1.613", root="तिल्ल", meaning="इत्येके", gana="Bhvadi")
def root_1_613():
    """
    1.613 तिल्ल इत्येके 
    """
    return "तिल्ल"


@registry.register("1.619", root="वेल्ल", meaning="चलने", gana="Bhvadi")
def root_1_619():
    """
    1.619 वेल्ल चलने 
    """
    return "वेल्ल"


@registry.register("1.620", root="वेह्ल", meaning="इत्येके", gana="Bhvadi")
def root_1_620():
    """
    1.620 वेह्ल इत्येके 
    """
    return "वेह्ल"


@registry.register("1.621", root="पेलृऽ", meaning="पल्लऽ", gana="Bhvadi")
def root_1_621():
    """
    1.621 पेलृऽ पल्लऽ
    """
    return "पेलृऽ"


@registry.register("1.623", root="शेलृ", meaning="गतौ", gana="Bhvadi")
def root_1_623():
    """
    1.623 शेलृ गतौ 
    """
    return "शेलृ"


@registry.register("1.624", root="षेलृ", meaning="इत्येके", gana="Bhvadi")
def root_1_624():
    """
    1.624 षेलृ इत्येके 
    """
    return "षेलृ"


@registry.register("1.625", root="स्खल", meaning="सञ्चलने", gana="Bhvadi")
def root_1_625():
    """
    1.625 स्खल सञ्चलने 
    """
    return "स्खल"


@registry.register("1.626", root="खल", meaning="सञ्चये च", gana="Bhvadi")
def root_1_626():
    """
    1.626 खल सञ्चये च 
    """
    return "खल"


@registry.register("1.627", root="गल", meaning="अदने भक्षणे स्रावे च", gana="Bhvadi")
def root_1_627():
    """
    1.627 गल अदने भक्षणे स्रावे च 
    """
    return "गल"


@registry.register("1.628", root="षल", meaning="गतौ", gana="Bhvadi")
def root_1_628():
    """
    1.628 षल गतौ 
    """
    return "षल"


@registry.register("1.629", root="दल", meaning="विशरणे", gana="Bhvadi")
def root_1_629():
    """
    1.629 दल विशरणे 
    """
    return "दल"


@registry.register("1.631", root="श्वल्ल", meaning="आशुगमने", gana="Bhvadi")
def root_1_631():
    """
    1.631 श्वल्ल आशुगमने 
    """
    return "श्वल्ल"


@registry.register("1.633", root="खोरृ", meaning="गतिप्रतिघाते", gana="Bhvadi")
def root_1_633():
    """
    1.633 खोरृ गतिप्रतिघाते 
    """
    return "खोरृ"


@registry.register("1.634", root="धोरृ", meaning="गतिचातुर्ये", gana="Bhvadi")
def root_1_634():
    """
    1.634 धोरृ गतिचातुर्ये 
    """
    return "धोरृ"


@registry.register("1.635", root="त्सर", meaning="छद्मगतौ", gana="Bhvadi")
def root_1_635():
    """
    1.635 त्सर छद्मगतौ 
    """
    return "त्सर"


@registry.register("1.636", root="क्मर", meaning="हूर्छने", gana="Bhvadi")
def root_1_636():
    """
    1.636 क्मर हूर्छने 
    """
    return "क्मर"


@registry.register("1.638", root="वभ्रऽ", meaning="बभ्रऽ", gana="Bhvadi")
def root_1_638():
    """
    1.638 वभ्रऽ बभ्रऽ
    """
    return "वभ्रऽ"


@registry.register("1.640", root="चर", meaning="गत्यर्थाः", gana="Bhvadi")
def root_1_640():
    """
    1.640 चर गत्यर्थाः 
    """
    return "चर"


@registry.register("1.641", root="ष्ठिवु", meaning="निरसने", gana="Bhvadi")
def root_1_641():
    """
    1.641 ष्ठिवु निरसने 
    """
    return "ष्ठिवु"


@registry.register("1.642", root="जि", meaning="जये", gana="Bhvadi")
def root_1_642():
    """
    1.642 जि जये 
    """
    return "जि"


@registry.register("1.643", root="जीव", meaning="प्राणधारणे", gana="Bhvadi")
def root_1_643():
    """
    1.643 जीव प्राणधारणे 
    """
    return "जीव"


@registry.register("1.647", root="णीव", meaning="स्थौल्ये", gana="Bhvadi")
def root_1_647():
    """
    1.647 णीव स्थौल्ये 
    """
    return "णीव"


@registry.register("1.649", root="क्षेवु", meaning="निरसने", gana="Bhvadi")
def root_1_649():
    """
    1.649 क्षेवु निरसने 
    """
    return "क्षेवु"


@registry.register("1.654", root="धुर्वी", meaning="हिंसार्थाः", gana="Bhvadi")
def root_1_654():
    """
    1.654 धुर्वी हिंसार्थाः 
    """
    return "धुर्वी"


@registry.register("1.655", root="गुर्वी", meaning="उद्यमने", gana="Bhvadi")
def root_1_655():
    """
    1.655 गुर्वी उद्यमने 
    """
    return "गुर्वी"


@registry.register("1.656", root="मुर्वी", meaning="बन्धने", gana="Bhvadi")
def root_1_656():
    """
    1.656 मुर्वी बन्धने 
    """
    return "मुर्वी"


@registry.register("1.657", root="पुर्वऽ", meaning="पूर्वऽ", gana="Bhvadi")
def root_1_657():
    """
    1.657 पुर्वऽ पूर्वऽ
    """
    return "पुर्वऽ"


@registry.register("1.659", root="मर्व", meaning="पूरणे", gana="Bhvadi")
def root_1_659():
    """
    1.659 मर्व पूरणे 
    """
    return "मर्व"


@registry.register("1.660", root="चर्व", meaning="अदने", gana="Bhvadi")
def root_1_660():
    """
    1.660 चर्व अदने 
    """
    return "चर्व"


@registry.register("1.661", root="भर्वऽ", meaning="हिंसायाम्", gana="Bhvadi")
def root_1_661():
    """
    1.661 भर्वऽ हिंसायाम् 
    """
    return "भर्वऽ"


@registry.register("1.662", root="भर्ब", meaning="इत्येके", gana="Bhvadi")
def root_1_662():
    """
    1.662 भर्ब इत्येके 
    """
    return "भर्ब"


@registry.register("1.663", root="भर्भ", meaning="इत्यन्ये", gana="Bhvadi")
def root_1_663():
    """
    1.663 भर्भ इत्यन्ये 
    """
    return "भर्भ"


@registry.register("1.666", root="गर्व", meaning="दर्पे", gana="Bhvadi")
def root_1_666():
    """
    1.666 गर्व दर्पे 
    """
    return "गर्व"


@registry.register("1.669", root="षर्व", meaning="हिंसायाम्", gana="Bhvadi")
def root_1_669():
    """
    1.669 षर्व हिंसायाम् 
    """
    return "षर्व"


@registry.register("1.670", root="इवि", meaning="व्याप्तौ", gana="Bhvadi")
def root_1_670():
    """
    1.670 इवि व्याप्तौ 
    """
    return "इवि"


@registry.register("1.673", root="णिवि", meaning="सेचने", gana="Bhvadi")
def root_1_673():
    """
    1.673 णिवि सेचने 
    """
    return "णिवि"


@registry.register("1.674", root="षिवि", meaning="इत्येके", gana="Bhvadi")
def root_1_674():
    """
    1.674 षिवि इत्येके 
    """
    return "षिवि"


@registry.register("1.678", root="जिवि", meaning="प्रीणनार्थाः", gana="Bhvadi")
def root_1_678():
    """
    1.678 जिवि प्रीणनार्थाः 
    """
    return "जिवि"


@registry.register("1.681", root="धवि", meaning="गत्यर्थाः", gana="Bhvadi")
def root_1_681():
    """
    1.681 धवि गत्यर्थाः 
    """
    return "धवि"


@registry.register("1.682", root="कृवि", meaning="हिंसाकरणयोश्च", gana="Bhvadi")
def root_1_682():
    """
    1.682 कृवि हिंसाकरणयोश्च 
    """
    return "कृवि"


@registry.register("1.683", root="मव", meaning="बन्धने", gana="Bhvadi")
def root_1_683():
    """
    1.683 मव बन्धने 
    """
    return "मव"


@registry.register("1.684", root="अव", meaning="रक्षणगतिकान्तिप्रीतितृप्त्यवगमप्रवेशऽ", gana="Bhvadi")
def root_1_684():
    """
    1.684 अव रक्षणगतिकान्तिप्रीतितृप्त्यवगमप्रवेशऽ
    """
    return "अव"


@registry.register("1.685", root="धावु", meaning="गतिशुद्ध्योः", gana="Bhvadi")
def root_1_685():
    """
    1.685 धावु गतिशुद्ध्योः 
    """
    return "धावु"


@registry.register("1.687", root="धिक्ष", meaning="सन्दीपनक्लेशनजीवनेषु", gana="Bhvadi")
def root_1_687():
    """
    1.687 धिक्ष सन्दीपनक्लेशनजीवनेषु 
    """
    return "धिक्ष"


@registry.register("1.688", root="वृक्ष", meaning="वरणे", gana="Bhvadi")
def root_1_688():
    """
    1.688 वृक्ष वरणे 
    """
    return "वृक्ष"


@registry.register("1.689", root="शिक्ष", meaning="विद्योपादाने", gana="Bhvadi")
def root_1_689():
    """
    1.689 शिक्ष विद्योपादाने 
    """
    return "शिक्ष"


@registry.register("1.690", root="भिक्ष", meaning="भिक्षायामलाभे लाभे च", gana="Bhvadi")
def root_1_690():
    """
    1.690 भिक्ष भिक्षायामलाभे लाभे च 
    """
    return "भिक्ष"


@registry.register("1.691", root="क्लेश", meaning="अव्यक्तायां वाचि", gana="Bhvadi")
def root_1_691():
    """
    1.691 क्लेश अव्यक्तायां वाचि 
    """
    return "क्लेश"


@registry.register("1.692", root="दक्ष", meaning="वृद्धौ शीघ्रार्थे च", gana="Bhvadi")
def root_1_692():
    """
    1.692 दक्ष वृद्धौ शीघ्रार्थे च 
    """
    return "दक्ष"


@registry.register("1.693", root="दीक्ष", meaning="मौण्ड्येज्योपनयननियमव्रतादेशेषु", gana="Bhvadi")
def root_1_693():
    """
    1.693 दीक्ष मौण्ड्येज्योपनयननियमव्रतादेशेषु 
    """
    return "दीक्ष"


@registry.register("1.694", root="ईक्ष", meaning="दर्शने", gana="Bhvadi")
def root_1_694():
    """
    1.694 ईक्ष दर्शने 
    """
    return "ईक्ष"


@registry.register("1.695", root="ईष", meaning="गतिहिंसादर्शनेषु", gana="Bhvadi")
def root_1_695():
    """
    1.695 ईष गतिहिंसादर्शनेषु 
    """
    return "ईष"


@registry.register("1.696", root="भाष", meaning="व्यक्तायां वाचि", gana="Bhvadi")
def root_1_696():
    """
    1.696 भाष व्यक्तायां वाचि 
    """
    return "भाष"


@registry.register("1.697", root="वर्ष", meaning="स्नेहने", gana="Bhvadi")
def root_1_697():
    """
    1.697 वर्ष स्नेहने 
    """
    return "वर्ष"


@registry.register("1.698", root="गेषृ", meaning="अन्विच्छायाम्", gana="Bhvadi")
def root_1_698():
    """
    1.698 गेषृ अन्विच्छायाम् 
    """
    return "गेषृ"


@registry.register("1.699", root="ग्लेषृ", meaning="इत्येके", gana="Bhvadi")
def root_1_699():
    """
    1.699 ग्लेषृ इत्येके 
    """
    return "ग्लेषृ"


@registry.register("1.700", root="पेषृ", meaning="प्रयत्ने", gana="Bhvadi")
def root_1_700():
    """
    1.700 पेषृ प्रयत्ने 
    """
    return "पेषृ"


@registry.register("1.701", root="एषृ", meaning="इत्येके", gana="Bhvadi")
def root_1_701():
    """
    1.701 एषृ इत्येके 
    """
    return "एषृ"


@registry.register("1.702", root="येषृ", meaning="इत्यन्ये", gana="Bhvadi")
def root_1_702():
    """
    1.702 येषृ इत्यन्ये 
    """
    return "येषृ"


@registry.register("1.706", root="प्रेषृ", meaning="गतौ", gana="Bhvadi")
def root_1_706():
    """
    1.706 प्रेषृ गतौ 
    """
    return "प्रेषृ"


@registry.register("1.709", root="ह्रेषृ", meaning="अव्यक्ते शब्दे", gana="Bhvadi")
def root_1_709():
    """
    1.709 ह्रेषृ अव्यक्ते शब्दे 
    """
    return "ह्रेषृ"


@registry.register("1.710", root="कासृ", meaning="शब्दकुत्सायाम्", gana="Bhvadi")
def root_1_710():
    """
    1.710 कासृ शब्दकुत्सायाम् 
    """
    return "कासृ"


@registry.register("1.711", root="भासृ", meaning="दीप्तौ", gana="Bhvadi")
def root_1_711():
    """
    1.711 भासृ दीप्तौ 
    """
    return "भासृ"


@registry.register("1.713", root="रासृ", meaning="शब्दे", gana="Bhvadi")
def root_1_713():
    """
    1.713 रासृ शब्दे 
    """
    return "रासृ"


@registry.register("1.714", root="णस", meaning="कौटिल्ये", gana="Bhvadi")
def root_1_714():
    """
    1.714 णस कौटिल्ये 
    """
    return "णस"


@registry.register("1.715", root="भ्यस", meaning="भये", gana="Bhvadi")
def root_1_715():
    """
    1.715 भ्यस भये 
    """
    return "भ्यस"


@registry.register("1.716", root="आङः", meaning="शसि इच्छायाम्", gana="Bhvadi")
def root_1_716():
    """
    1.716 आङः शसि इच्छायाम् 
    """
    return "आङः"


@registry.register("1.718", root="ग्लसु", meaning="अदने", gana="Bhvadi")
def root_1_718():
    """
    1.718 ग्लसु अदने 
    """
    return "ग्लसु"


@registry.register("1.719", root="ईह", meaning="चेष्टायाम्", gana="Bhvadi")
def root_1_719():
    """
    1.719 ईह चेष्टायाम् 
    """
    return "ईह"


@registry.register("1.721", root="महि", meaning="वृद्धौ", gana="Bhvadi")
def root_1_721():
    """
    1.721 महि वृद्धौ 
    """
    return "महि"


@registry.register("1.722", root="अहि", meaning="गतौ", gana="Bhvadi")
def root_1_722():
    """
    1.722 अहि गतौ 
    """
    return "अहि"


@registry.register("1.724", root="गल्ह", meaning="कुत्सायाम्", gana="Bhvadi")
def root_1_724():
    """
    1.724 गल्ह कुत्सायाम् 
    """
    return "गल्ह"


@registry.register("1.726", root="बल्ह", meaning="प्राधान्ये", gana="Bhvadi")
def root_1_726():
    """
    1.726 बल्ह प्राधान्ये 
    """
    return "बल्ह"


@registry.register("1.728", root="वल्ह", meaning="परिभाषणहिंसाच्छादनेषु", gana="Bhvadi")
def root_1_728():
    """
    1.728 वल्ह परिभाषणहिंसाच्छादनेषु 
    """
    return "वल्ह"


@registry.register("1.729", root="प्लिह", meaning="गतौ", gana="Bhvadi")
def root_1_729():
    """
    1.729 प्लिह गतौ 
    """
    return "प्लिह"


@registry.register("1.730", root="वेहृऽ", meaning="बेहृऽ", gana="Bhvadi")
def root_1_730():
    """
    1.730 वेहृऽ बेहृऽ
    """
    return "वेहृऽ"


@registry.register("1.732", root="बाहृऽ", meaning="वाहृ प्रयत्ने", gana="Bhvadi")
def root_1_732():
    """
    1.732 बाहृऽ वाहृ प्रयत्ने 
    """
    return "बाहृऽ"


@registry.register("1.733", root="द्राहृ", meaning="निद्राक्षये", gana="Bhvadi")
def root_1_733():
    """
    1.733 द्राहृ निद्राक्षये 
    """
    return "द्राहृ"


@registry.register("1.734", root="काश‍ृ", meaning="दीप्तौ", gana="Bhvadi")
def root_1_734():
    """
    1.734 काश‍ृ दीप्तौ 
    """
    return "काश‍ृ"


@registry.register("1.735", root="ऊह", meaning="वितर्के", gana="Bhvadi")
def root_1_735():
    """
    1.735 ऊह वितर्के 
    """
    return "ऊह"


@registry.register("1.736", root="गाहू", meaning="विलोडने", gana="Bhvadi")
def root_1_736():
    """
    1.736 गाहू विलोडने 
    """
    return "गाहू"


@registry.register("1.737", root="गृहू", meaning="ग्रहणे", gana="Bhvadi")
def root_1_737():
    """
    1.737 गृहू ग्रहणे 
    """
    return "गृहू"


@registry.register("1.738", root="ग्लह", meaning="च अपादाने", gana="Bhvadi")
def root_1_738():
    """
    1.738 ग्लह च अपादाने 
    """
    return "ग्लह"


@registry.register("1.739", root="घुषि", meaning="कान्तिकरणे", gana="Bhvadi")
def root_1_739():
    """
    1.739 घुषि कान्तिकरणे 
    """
    return "घुषि"


@registry.register("1.740", root="घष", meaning="इति केचित्", gana="Bhvadi")
def root_1_740():
    """
    1.740 घष इति केचित् 
    """
    return "घष"


@registry.register("1.741", root="घुषिर्", meaning="अविशब्दने", gana="Bhvadi")
def root_1_741():
    """
    1.741 घुषिर् अविशब्दने 
    """
    return "घुषिर्"


@registry.register("1.742", root="अक्षू", meaning="व्याप्तौ", gana="Bhvadi")
def root_1_742():
    """
    1.742 अक्षू व्याप्तौ 
    """
    return "अक्षू"


@registry.register("1.744", root="त्वक्षू", meaning="तनूकरणे", gana="Bhvadi")
def root_1_744():
    """
    1.744 त्वक्षू तनूकरणे 
    """
    return "त्वक्षू"


@registry.register("1.745", root="उक्ष", meaning="सेचने", gana="Bhvadi")
def root_1_745():
    """
    1.745 उक्ष सेचने 
    """
    return "उक्ष"


@registry.register("1.746", root="रक्ष", meaning="पालने", gana="Bhvadi")
def root_1_746():
    """
    1.746 रक्ष पालने 
    """
    return "रक्ष"


@registry.register("1.747", root="णिक्ष", meaning="चुम्बने", gana="Bhvadi")
def root_1_747():
    """
    1.747 णिक्ष चुम्बने 
    """
    return "णिक्ष"


@registry.register("1.752", root="णक्ष", meaning="गतौ", gana="Bhvadi")
def root_1_752():
    """
    1.752 णक्ष गतौ 
    """
    return "णक्ष"


@registry.register("1.753", root="वक्ष", meaning="रोषे", gana="Bhvadi")
def root_1_753():
    """
    1.753 वक्ष रोषे 
    """
    return "वक्ष"


@registry.register("1.754", root="मृक्ष", meaning="सङ्घाते", gana="Bhvadi")
def root_1_754():
    """
    1.754 मृक्ष सङ्घाते 
    """
    return "मृक्ष"


@registry.register("1.755", root="म्रक्ष", meaning="इत्येके", gana="Bhvadi")
def root_1_755():
    """
    1.755 म्रक्ष इत्येके 
    """
    return "म्रक्ष"


@registry.register("1.756", root="तक्ष", meaning="त्वचने", gana="Bhvadi")
def root_1_756():
    """
    1.756 तक्ष त्वचने 
    """
    return "तक्ष"


@registry.register("1.757", root="पक्ष", meaning="परिग्रह इत्येके", gana="Bhvadi")
def root_1_757():
    """
    1.757 पक्ष परिग्रह इत्येके 
    """
    return "पक्ष"


@registry.register("1.758", root="सूर्क्ष", meaning="आदरे", gana="Bhvadi")
def root_1_758():
    """
    1.758 सूर्क्ष आदरे 
    """
    return "सूर्क्ष"


@registry.register("1.759", root="षर्क्ष", meaning="इति केचित्", gana="Bhvadi")
def root_1_759():
    """
    1.759 षर्क्ष इति केचित् 
    """
    return "षर्क्ष"


@registry.register("1.762", root="माक्षि", meaning="काङ्क्षायाम्", gana="Bhvadi")
def root_1_762():
    """
    1.762 माक्षि काङ्क्षायाम् 
    """
    return "माक्षि"


@registry.register("1.765", root="ध्वाक्षि", meaning="घोरवासिते च", gana="Bhvadi")
def root_1_765():
    """
    1.765 ध्वाक्षि घोरवासिते च 
    """
    return "ध्वाक्षि"


@registry.register("1.766", root="ध्माक्षि", meaning="इत्येके", gana="Bhvadi")
def root_1_766():
    """
    1.766 ध्माक्षि इत्येके 
    """
    return "ध्माक्षि"


@registry.register("1.767", root="चूष", meaning="पाने", gana="Bhvadi")
def root_1_767():
    """
    1.767 चूष पाने 
    """
    return "चूष"


@registry.register("1.768", root="तूष", meaning="तुष्टौ", gana="Bhvadi")
def root_1_768():
    """
    1.768 तूष तुष्टौ 
    """
    return "तूष"


@registry.register("1.769", root="पूष", meaning="वृद्धौ", gana="Bhvadi")
def root_1_769():
    """
    1.769 पूष वृद्धौ 
    """
    return "पूष"


@registry.register("1.770", root="मूष", meaning="स्तेये", gana="Bhvadi")
def root_1_770():
    """
    1.770 मूष स्तेये 
    """
    return "मूष"


@registry.register("1.772", root="रूष", meaning="भूषायाम्", gana="Bhvadi")
def root_1_772():
    """
    1.772 रूष भूषायाम् 
    """
    return "रूष"


@registry.register("1.773", root="शूष", meaning="प्रसवे", gana="Bhvadi")
def root_1_773():
    """
    1.773 शूष प्रसवे 
    """
    return "शूष"


@registry.register("1.774", root="सूष", meaning="इत्येके", gana="Bhvadi")
def root_1_774():
    """
    1.774 सूष इत्येके 
    """
    return "सूष"


@registry.register("1.775", root="यूष", meaning="हिंसायाम्", gana="Bhvadi")
def root_1_775():
    """
    1.775 यूष हिंसायाम् 
    """
    return "यूष"


@registry.register("1.776", root="जूष", meaning="च", gana="Bhvadi")
def root_1_776():
    """
    1.776 जूष च 
    """
    return "जूष"


@registry.register("1.778", root="तसि", meaning="अलङ्कारे", gana="Bhvadi")
def root_1_778():
    """
    1.778 तसि अलङ्कारे 
    """
    return "तसि"


@registry.register("1.779", root="ऊष", meaning="रुजायाम्", gana="Bhvadi")
def root_1_779():
    """
    1.779 ऊष रुजायाम् 
    """
    return "ऊष"


@registry.register("1.780", root="ईष", meaning="उञ्छे", gana="Bhvadi")
def root_1_780():
    """
    1.780 ईष उञ्छे 
    """
    return "ईष"


@registry.register("1.790", root="रिष", meaning="हिंसार्थाः", gana="Bhvadi")
def root_1_790():
    """
    1.790 रिष हिंसार्थाः 
    """
    return "रिष"


@registry.register("1.791", root="भष", meaning="भर्त्सने", gana="Bhvadi")
def root_1_791():
    """
    1.791 भष भर्त्सने 
    """
    return "भष"


@registry.register("1.792", root="उष", meaning="दाहे", gana="Bhvadi")
def root_1_792():
    """
    1.792 उष दाहे 
    """
    return "उष"


@registry.register("1.796", root="णिषु", meaning="सेचने", gana="Bhvadi")
def root_1_796():
    """
    1.796 णिषु सेचने 
    """
    return "णिषु"


@registry.register("1.797", root="पुष", meaning="पुष्टौ", gana="Bhvadi")
def root_1_797():
    """
    1.797 पुष पुष्टौ 
    """
    return "पुष"


@registry.register("1.801", root="प्लुषु", meaning="दाहे", gana="Bhvadi")
def root_1_801():
    """
    1.801 प्लुषु दाहे 
    """
    return "प्लुषु"


@registry.register("1.804", root="मृषु", meaning="सेचने", gana="Bhvadi")
def root_1_804():
    """
    1.804 मृषु सेचने 
    """
    return "मृषु"


@registry.register("1.805", root="घृषु", meaning="सङ्घर्षे", gana="Bhvadi")
def root_1_805():
    """
    1.805 घृषु सङ्घर्षे 
    """
    return "घृषु"


@registry.register("1.806", root="हृषु", meaning="अलीके", gana="Bhvadi")
def root_1_806():
    """
    1.806 हृषु अलीके 
    """
    return "हृषु"


@registry.register("1.808", root="ह्रसऽ", meaning="हृसऽ", gana="Bhvadi")
def root_1_808():
    """
    1.808 ह्रसऽ हृसऽ
    """
    return "ह्रसऽ"


@registry.register("1.810", root="रस", meaning="शब्दे", gana="Bhvadi")
def root_1_810():
    """
    1.810 रस शब्दे 
    """
    return "रस"


@registry.register("1.811", root="लस", meaning="श्लेषणक्रीडनयोः च", gana="Bhvadi")
def root_1_811():
    """
    1.811 लस श्लेषणक्रीडनयोः च 
    """
    return "लस"


@registry.register("1.812", root="घसॢ", meaning="अदने", gana="Bhvadi")
def root_1_812():
    """
    1.812 घसॢ अदने 
    """
    return "घसॢ"


@registry.register("1.813", root="जर्त्सऽ", meaning="जर्जऽ जर्चऽ", gana="Bhvadi")
def root_1_813():
    """
    1.813 जर्त्सऽ जर्जऽ जर्चऽ
    """
    return "जर्त्सऽ"


@registry.register("1.815", root="झर्त्स", meaning="झर्झ झर्ज परिभाषणहिंसातर्जनेषु", gana="Bhvadi")
def root_1_815():
    """
    1.815 झर्त्स झर्झ झर्ज परिभाषणहिंसातर्जनेषु 
    """
    return "झर्त्स"


@registry.register("1.821", root="बेस", meaning="गतौ", gana="Bhvadi")
def root_1_821():
    """
    1.821 बेस गतौ 
    """
    return "बेस"


@registry.register("1.822", root="हसे", meaning="हसने", gana="Bhvadi")
def root_1_822():
    """
    1.822 हसे हसने 
    """
    return "हसे"


@registry.register("1.823", root="णिश", meaning="समाधौ", gana="Bhvadi")
def root_1_823():
    """
    1.823 णिश समाधौ 
    """
    return "णिश"


@registry.register("1.825", root="मश", meaning="शब्दे", gana="Bhvadi")
def root_1_825():
    """
    1.825 मश शब्दे 
    """
    return "मश"


@registry.register("1.826", root="शव", meaning="गतौ", gana="Bhvadi")
def root_1_826():
    """
    1.826 शव गतौ 
    """
    return "शव"


@registry.register("1.827", root="शश", meaning="प्लुतगतौ", gana="Bhvadi")
def root_1_827():
    """
    1.827 शश प्लुतगतौ 
    """
    return "शश"


@registry.register("1.828", root="शसु", meaning="हिंसायाम्", gana="Bhvadi")
def root_1_828():
    """
    1.828 शसु हिंसायाम् 
    """
    return "शसु"


@registry.register("1.829", root="शंसु", meaning="स्तुतौ", gana="Bhvadi")
def root_1_829():
    """
    1.829 शंसु स्तुतौ 
    """
    return "शंसु"


@registry.register("1.830", root="चह", meaning="परिकल्कने", gana="Bhvadi")
def root_1_830():
    """
    1.830 चह परिकल्कने 
    """
    return "चह"


@registry.register("1.831", root="मह", meaning="पूजायाम्", gana="Bhvadi")
def root_1_831():
    """
    1.831 मह पूजायाम् 
    """
    return "मह"


@registry.register("1.832", root="रह", meaning="त्यागे", gana="Bhvadi")
def root_1_832():
    """
    1.832 रह त्यागे 
    """
    return "रह"


@registry.register("1.833", root="रहि", meaning="गतौ", gana="Bhvadi")
def root_1_833():
    """
    1.833 रहि गतौ 
    """
    return "रहि"


@registry.register("1.836", root="बृहऽ", meaning="वृहऽ", gana="Bhvadi")
def root_1_836():
    """
    1.836 बृहऽ वृहऽ
    """
    return "बृहऽ"


@registry.register("1.837", root="बृहि", meaning="वृहि वृद्धौ", gana="Bhvadi")
def root_1_837():
    """
    1.837 बृहि वृहि वृद्धौ 
    """
    return "बृहि"


@registry.register("1.840", root="उहिर्", meaning="अर्दने", gana="Bhvadi")
def root_1_840():
    """
    1.840 उहिर् अर्दने 
    """
    return "उहिर्"


@registry.register("1.841", root="अर्ह", meaning="पूजायाम्", gana="Bhvadi")
def root_1_841():
    """
    1.841 अर्ह पूजायाम् 
    """
    return "अर्ह"


@registry.register("1.842", root="द्युत", meaning="दीप्तौ", gana="Bhvadi")
def root_1_842():
    """
    1.842 द्युत दीप्तौ 
    """
    return "द्युत"


@registry.register("1.843", root="श्विता", meaning="वर्णे", gana="Bhvadi")
def root_1_843():
    """
    1.843 श्विता वर्णे 
    """
    return "श्विता"


@registry.register("1.844", root="ञिमिदा", meaning="स्नेहने", gana="Bhvadi")
def root_1_844():
    """
    1.844 ञिमिदा स्नेहने 
    """
    return "ञिमिदा"


@registry.register("1.845", root="ञिष्विदा", meaning="स्नेहनमोचनयोः गात्रप्रस्रवणे", gana="Bhvadi")
def root_1_845():
    """
    1.845 ञिष्विदा स्नेहनमोचनयोः गात्रप्रस्रवणे 
    """
    return "ञिष्विदा"


@registry.register("1.846", root="ञिक्ष्विदा", meaning="चेत्येके", gana="Bhvadi")
def root_1_846():
    """
    1.846 ञिक्ष्विदा चेत्येके 
    """
    return "ञिक्ष्विदा"


@registry.register("1.847", root="रुच", meaning="दीप्तावभिप्रीतौ च", gana="Bhvadi")
def root_1_847():
    """
    1.847 रुच दीप्तावभिप्रीतौ च 
    """
    return "रुच"


@registry.register("1.848", root="घुट", meaning="परिवर्तने", gana="Bhvadi")
def root_1_848():
    """
    1.848 घुट परिवर्तने 
    """
    return "घुट"


@registry.register("1.852", root="उठ", meaning="उपघाते प्रतिघाते", gana="Bhvadi")
def root_1_852():
    """
    1.852 उठ उपघाते प्रतिघाते 
    """
    return "उठ"


@registry.register("1.853", root="शुभ", meaning="दीप्तौ", gana="Bhvadi")
def root_1_853():
    """
    1.853 शुभ दीप्तौ 
    """
    return "शुभ"


@registry.register("1.854", root="क्षुभ", meaning="सञ्चलने", gana="Bhvadi")
def root_1_854():
    """
    1.854 क्षुभ सञ्चलने 
    """
    return "क्षुभ"


@registry.register("1.856", root="तुभ", meaning="हिंसायाम्", gana="Bhvadi")
def root_1_856():
    """
    1.856 तुभ हिंसायाम् 
    """
    return "तुभ"


@registry.register("1.857", root="स्रंसुऽ", meaning="श्रंसुऽ श्रंशुऽ", gana="Bhvadi")
def root_1_857():
    """
    1.857 स्रंसुऽ श्रंसुऽ श्रंशुऽ
    """
    return "स्रंसुऽ"


@registry.register("1.859", root="भ्रंसु", meaning="अवस्रंसने", gana="Bhvadi")
def root_1_859():
    """
    1.859 भ्रंसु अवस्रंसने 
    """
    return "भ्रंसु"


@registry.register("1.860", root="भ्रंशु", meaning="इत्यपि केचित् तृतीय एव तालव्यान्त इत्यन्ये", gana="Bhvadi")
def root_1_860():
    """
    1.860 भ्रंशु इत्यपि केचित् तृतीय एव तालव्यान्त इत्यन्ये 
    """
    return "भ्रंशु"


@registry.register("1.861", root="स्रम्भु", meaning="विश्वासे", gana="Bhvadi")
def root_1_861():
    """
    1.861 स्रम्भु विश्वासे 
    """
    return "स्रम्भु"


@registry.register("1.862", root="वृतु", meaning="वर्तने", gana="Bhvadi")
def root_1_862():
    """
    1.862 वृतु वर्तने 
    """
    return "वृतु"


@registry.register("1.863", root="वृधु", meaning="वृधौ", gana="Bhvadi")
def root_1_863():
    """
    1.863 वृधु वृधौ 
    """
    return "वृधु"


@registry.register("1.864", root="श‍ृधु", meaning="शब्दकुत्सायाम्", gana="Bhvadi")
def root_1_864():
    """
    1.864 श‍ृधु शब्दकुत्सायाम् 
    """
    return "श‍ृधु"


@registry.register("1.865", root="स्यन्दू", meaning="प्रस्रवणे", gana="Bhvadi")
def root_1_865():
    """
    1.865 स्यन्दू प्रस्रवणे 
    """
    return "स्यन्दू"


@registry.register("1.866", root="कृपू", meaning="सामर्थ्ये", gana="Bhvadi")
def root_1_866():
    """
    1.866 कृपू सामर्थ्ये 
    """
    return "कृपू"


@registry.register("1.867", root="घटम्", meaning="चेष्टायाम्", gana="Bhvadi")
def root_1_867():
    """
    1.867 घटम् चेष्टायाम् 
    """
    return "घटम्"


@registry.register("1.868", root="व्यथम्", meaning="भयसञ्चलनयोः", gana="Bhvadi")
def root_1_868():
    """
    1.868 व्यथम् भयसञ्चलनयोः 
    """
    return "व्यथम्"


@registry.register("1.869", root="प्रथम्", meaning="प्रख्याने", gana="Bhvadi")
def root_1_869():
    """
    1.869 प्रथम् प्रख्याने 
    """
    return "प्रथम्"


@registry.register("1.870", root="प्रसम्", meaning="विस्तारे", gana="Bhvadi")
def root_1_870():
    """
    1.870 प्रसम् विस्तारे 
    """
    return "प्रसम्"


@registry.register("1.871", root="म्रदम्", meaning="मर्दने", gana="Bhvadi")
def root_1_871():
    """
    1.871 म्रदम् मर्दने 
    """
    return "म्रदम्"


@registry.register("1.872", root="स्खदम्", meaning="स्खदने", gana="Bhvadi")
def root_1_872():
    """
    1.872 स्खदम् स्खदने 
    """
    return "स्खदम्"


@registry.register("1.873", root="क्षजिम्", meaning="गतिदानयोः", gana="Bhvadi")
def root_1_873():
    """
    1.873 क्षजिम् गतिदानयोः 
    """
    return "क्षजिम्"


@registry.register("1.874", root="दक्षम्", meaning="गतिहिंसनयोः गतिशासनयोः", gana="Bhvadi")
def root_1_874():
    """
    1.874 दक्षम् गतिहिंसनयोः गतिशासनयोः
    """
    return "दक्षम्"


@registry.register("1.875", root="कृपम्", meaning="कृपायां गतौ च", gana="Bhvadi")
def root_1_875():
    """
    1.875 कृपम् कृपायां गतौ च 
    """
    return "कृपम्"


@registry.register("1.876", root="क्रपम्", meaning="इत्येके", gana="Bhvadi")
def root_1_876():
    """
    1.876 क्रपम् इत्येके 
    """
    return "क्रपम्"


@registry.register("1.877", root="कपम्", meaning="इत्यन्ये", gana="Bhvadi")
def root_1_877():
    """
    1.877 कपम् इत्यन्ये 
    """
    return "कपम्"


@registry.register("1.880", root="क्लदिम्", meaning="वैक्लव्ये", gana="Bhvadi")
def root_1_880():
    """
    1.880 क्लदिम् वैक्लव्ये 
    """
    return "क्लदिम्"


@registry.register("1.883", root="क्लदम्", meaning="इत्यन्ये ॥", gana="Bhvadi")
def root_1_883():
    """
    1.883 क्लदम् इत्यन्ये ॥
    """
    return "क्लदम्"


@registry.register("1.884", root="ञित्वराम्", meaning="सम्भ्रमे", gana="Bhvadi")
def root_1_884():
    """
    1.884 ञित्वराम् सम्भ्रमे 
    """
    return "ञित्वराम्"


@registry.register("1.885", root="ज्वरम्", meaning="रोगे", gana="Bhvadi")
def root_1_885():
    """
    1.885 ज्वरम् रोगे 
    """
    return "ज्वरम्"


@registry.register("1.886", root="गडम्", meaning="सेचने", gana="Bhvadi")
def root_1_886():
    """
    1.886 गडम् सेचने 
    """
    return "गडम्"


@registry.register("1.887", root="हेडम्", meaning="वेष्टने", gana="Bhvadi")
def root_1_887():
    """
    1.887 हेडम् वेष्टने 
    """
    return "हेडम्"


@registry.register("1.889", root="भटम्", meaning="परिभाषणे", gana="Bhvadi")
def root_1_889():
    """
    1.889 भटम् परिभाषणे 
    """
    return "भटम्"


@registry.register("1.890", root="णटम्", meaning="नृत्तौ", gana="Bhvadi")
def root_1_890():
    """
    1.890 णटम् नृत्तौ 
    """
    return "णटम्"


@registry.register("1.891", root="ष्टकम्", meaning="प्रतिघाते प्रतीघाते", gana="Bhvadi")
def root_1_891():
    """
    1.891 ष्टकम् प्रतिघाते प्रतीघाते 
    """
    return "ष्टकम्"


@registry.register("1.892", root="चकम्", meaning="तृप्तौ", gana="Bhvadi")
def root_1_892():
    """
    1.892 चकम् तृप्तौ 
    """
    return "चकम्"


@registry.register("1.893", root="कखेम्", meaning="हसने", gana="Bhvadi")
def root_1_893():
    """
    1.893 कखेम् हसने 
    """
    return "कखेम्"


@registry.register("1.894", root="रगेम्", meaning="शङ्कायाम्", gana="Bhvadi")
def root_1_894():
    """
    1.894 रगेम् शङ्कायाम् 
    """
    return "रगेम्"


@registry.register("1.895", root="लगेम्", meaning="सङ्गे", gana="Bhvadi")
def root_1_895():
    """
    1.895 लगेम् सङ्गे 
    """
    return "लगेम्"


@registry.register("1.899", root="ष्ठगेम्", meaning="संवरणे", gana="Bhvadi")
def root_1_899():
    """
    1.899 ष्ठगेम् संवरणे 
    """
    return "ष्ठगेम्"


@registry.register("1.900", root="कगेम्", meaning="नोच्यते", gana="Bhvadi")
def root_1_900():
    """
    1.900 कगेम् नोच्यते 
    """
    return "कगेम्"


@registry.register("1.902", root="अगम्", meaning="कुटिलायां गतौ", gana="Bhvadi")
def root_1_902():
    """
    1.902 अगम् कुटिलायां गतौ 
    """
    return "अगम्"


@registry.register("1.904", root="रणम्", meaning="गतौ", gana="Bhvadi")
def root_1_904():
    """
    1.904 रणम् गतौ 
    """
    return "रणम्"


@registry.register("1.907", root="श्रणम्", meaning="दाने च", gana="Bhvadi")
def root_1_907():
    """
    1.907 श्रणम् दाने च 
    """
    return "श्रणम्"


@registry.register("1.913", root="क्लथम्", meaning="हिंसार्थाः", gana="Bhvadi")
def root_1_913():
    """
    1.913 क्लथम् हिंसार्थाः 
    """
    return "क्लथम्"


@registry.register("1.914", root="चनम्", meaning="च", gana="Bhvadi")
def root_1_914():
    """
    1.914 चनम् च 
    """
    return "चनम्"


@registry.register("1.915", root="वनुम्", meaning="च नोच्यते नोपलभ्यते", gana="Bhvadi")
def root_1_915():
    """
    1.915 वनुम् च नोच्यते नोपलभ्यते 
    """
    return "वनुम्"


@registry.register("1.916", root="ज्वलम्", meaning="दीप्तौ", gana="Bhvadi")
def root_1_916():
    """
    1.916 ज्वलम् दीप्तौ 
    """
    return "ज्वलम्"


@registry.register("1.918", root="ह्मलम्", meaning="सञ्चलने चलने", gana="Bhvadi")
def root_1_918():
    """
    1.918 ह्मलम् सञ्चलने चलने 
    """
    return "ह्मलम्"


@registry.register("1.919", root="स्मृम्", meaning="आध्याने", gana="Bhvadi")
def root_1_919():
    """
    1.919 स्मृम् आध्याने 
    """
    return "स्मृम्"


@registry.register("1.920", root="दृईम्", meaning="भये", gana="Bhvadi")
def root_1_920():
    """
    1.920 दृईम् भये 
    """
    return "दृईम्"


@registry.register("1.921", root="नृईम्", meaning="नये", gana="Bhvadi")
def root_1_921():
    """
    1.921 नृईम् नये 
    """
    return "नृईम्"


@registry.register("1.922", root="श्राम्", meaning="पाके", gana="Bhvadi")
def root_1_922():
    """
    1.922 श्राम् पाके 
    """
    return "श्राम्"


@registry.register("1.923", root="॥", meaning="मारणतोषणनिशामनेषु ज्ञाम्", gana="Bhvadi")
def root_1_923():
    """
    1.923 ॥ मारणतोषणनिशामनेषु ज्ञाम् 
    """
    return "॥"


@registry.register("1.924", root="॥", meaning="कम्पने चलिः ॥", gana="Bhvadi")
def root_1_924():
    """
    1.924 ॥ कम्पने चलिः ॥
    """
    return "॥"


@registry.register("1.925", root="॥", meaning="छदिर् ऊर्जने ॥", gana="Bhvadi")
def root_1_925():
    """
    1.925 ॥ छदिर् ऊर्जने ॥
    """
    return "॥"


@registry.register("1.926", root="॥", meaning="जिह्वोन्मथने लडिः ॥", gana="Bhvadi")
def root_1_926():
    """
    1.926 ॥ जिह्वोन्मथने लडिः ॥
    """
    return "॥"


@registry.register("1.927", root="॥", meaning="मदीम् हर्षग्लेपनयोः ॥", gana="Bhvadi")
def root_1_927():
    """
    1.927 ॥ मदीम् हर्षग्लेपनयोः ॥
    """
    return "॥"


@registry.register("1.928", root="॥", meaning="ध्वनम् शब्दे ॥", gana="Bhvadi")
def root_1_928():
    """
    1.928 ॥ ध्वनम् शब्दे ॥
    """
    return "॥"


@registry.register("1.929", root="॥", meaning="दलिऽ", gana="Bhvadi")
def root_1_929():
    """
    1.929 ॥ दलिऽ
    """
    return "॥"


@registry.register("1.930", root="॥", meaning="वलिऽ", gana="Bhvadi")
def root_1_930():
    """
    1.930 ॥ वलिऽ
    """
    return "॥"


@registry.register("1.931", root="॥", meaning="स्खलिऽ", gana="Bhvadi")
def root_1_931():
    """
    1.931 ॥ स्खलिऽ
    """
    return "॥"


@registry.register("1.932", root="॥", meaning="रणिऽ", gana="Bhvadi")
def root_1_932():
    """
    1.932 ॥ रणिऽ
    """
    return "॥"


@registry.register("1.933", root="॥", meaning="ध्वनिऽ", gana="Bhvadi")
def root_1_933():
    """
    1.933 ॥ ध्वनिऽ
    """
    return "॥"


@registry.register("1.934", root="॥", meaning="त्रपिऽ", gana="Bhvadi")
def root_1_934():
    """
    1.934 ॥ त्रपिऽ
    """
    return "॥"


@registry.register("1.935", root="॥", meaning="क्षपयश्च इति भोजः ॥", gana="Bhvadi")
def root_1_935():
    """
    1.935 ॥ क्षपयश्च इति भोजः ॥
    """
    return "॥"


@registry.register("1.936", root="॥", meaning="स्वनम् अवतंसने", gana="Bhvadi")
def root_1_936():
    """
    1.936 ॥ स्वनम् अवतंसने 
    """
    return "॥"


@registry.register("1.937", root="॥", meaning="जनीऽ", gana="Bhvadi")
def root_1_937():
    """
    1.937 ॥ जनीऽ
    """
    return "॥"


@registry.register("1.938", root="॥", meaning="जृईष्ऽ", gana="Bhvadi")
def root_1_938():
    """
    1.938 ॥ जृईष्ऽ
    """
    return "॥"


@registry.register("1.939", root="॥", meaning="क्नसुऽ", gana="Bhvadi")
def root_1_939():
    """
    1.939 ॥ क्नसुऽ
    """
    return "॥"


@registry.register("1.940", root="॥", meaning="रञ्जोऽमन्ताश्च ॥", gana="Bhvadi")
def root_1_940():
    """
    1.940 ॥ रञ्जोऽमन्ताश्च ॥
    """
    return "॥"


@registry.register("1.941", root="॥", meaning="ज्वलऽ", gana="Bhvadi")
def root_1_941():
    """
    1.941 ॥ ज्वलऽ
    """
    return "॥"


@registry.register("1.942", root="॥", meaning="ह्वलऽ", gana="Bhvadi")
def root_1_942():
    """
    1.942 ॥ ह्वलऽ
    """
    return "॥"


@registry.register("1.943", root="॥", meaning="ह्मलऽ", gana="Bhvadi")
def root_1_943():
    """
    1.943 ॥ ह्मलऽ
    """
    return "॥"


@registry.register("1.944", root="॥", meaning="नमामनुपसर्गाद्वा ॥", gana="Bhvadi")
def root_1_944():
    """
    1.944 ॥ नमामनुपसर्गाद्वा ॥
    """
    return "॥"


@registry.register("1.945", root="॥", meaning="ग्लाऽ", gana="Bhvadi")
def root_1_945():
    """
    1.945 ॥ ग्लाऽ
    """
    return "॥"


@registry.register("1.946", root="॥", meaning="स्नाऽ", gana="Bhvadi")
def root_1_946():
    """
    1.946 ॥ स्नाऽ
    """
    return "॥"


@registry.register("1.947", root="॥", meaning="वनुऽ", gana="Bhvadi")
def root_1_947():
    """
    1.947 ॥ वनुऽ
    """
    return "॥"


@registry.register("1.948", root="॥", meaning="वमां च ॥", gana="Bhvadi")
def root_1_948():
    """
    1.948 ॥ वमां च ॥
    """
    return "॥"


@registry.register("1.949", root="॥", meaning="न कमिऽ", gana="Bhvadi")
def root_1_949():
    """
    1.949 ॥ न कमिऽ
    """
    return "॥"


@registry.register("1.950", root="॥", meaning="अमिऽ", gana="Bhvadi")
def root_1_950():
    """
    1.950 ॥ अमिऽ
    """
    return "॥"


@registry.register("1.951", root="॥", meaning="चमाम् ॥", gana="Bhvadi")
def root_1_951():
    """
    1.951 ॥ चमाम् ॥
    """
    return "॥"


@registry.register("1.952", root="॥", meaning="शमो दर्शने ॥", gana="Bhvadi")
def root_1_952():
    """
    1.952 ॥ शमो दर्शने ॥
    """
    return "॥"


@registry.register("1.953", root="॥", meaning="यमोऽपरिवेषणे ॥", gana="Bhvadi")
def root_1_953():
    """
    1.953 ॥ यमोऽपरिवेषणे ॥
    """
    return "॥"


@registry.register("1.954", root="॥", meaning="स्खदिर् अवपरिभ्यां च ॥", gana="Bhvadi")
def root_1_954():
    """
    1.954 ॥ स्खदिर् अवपरिभ्यां च ॥
    """
    return "॥"


@registry.register("1.955", root="फणम्", meaning="गतौ गतिदीप्त्योः", gana="Bhvadi")
def root_1_955():
    """
    1.955 फणम् गतौ गतिदीप्त्योः 
    """
    return "फणम्"


@registry.register("1.956", root="राजृ", meaning="दीप्तौ", gana="Bhvadi")
def root_1_956():
    """
    1.956 राजृ दीप्तौ 
    """
    return "राजृ"


@registry.register("1.959", root="टुभ्लाश‍ृ", meaning="दीप्तौ", gana="Bhvadi")
def root_1_959():
    """
    1.959 टुभ्लाश‍ृ दीप्तौ 
    """
    return "टुभ्लाश‍ृ"


@registry.register("1.962", root="ध्वन", meaning="शब्दे", gana="Bhvadi")
def root_1_962():
    """
    1.962 ध्वन शब्दे 
    """
    return "ध्वन"


@registry.register("1.964", root="ष्टम", meaning="अवैकल्ये वैकल्ये", gana="Bhvadi")
def root_1_964():
    """
    1.964 ष्टम अवैकल्ये वैकल्ये 
    """
    return "ष्टम"


@registry.register("1.965", root="ज्वल", meaning="दीप्तौ", gana="Bhvadi")
def root_1_965():
    """
    1.965 ज्वल दीप्तौ 
    """
    return "ज्वल"


@registry.register("1.966", root="चल", meaning="कम्पने", gana="Bhvadi")
def root_1_966():
    """
    1.966 चल कम्पने 
    """
    return "चल"


@registry.register("1.967", root="जल", meaning="घातने", gana="Bhvadi")
def root_1_967():
    """
    1.967 जल घातने 
    """
    return "जल"


@registry.register("1.969", root="ट्वल", meaning="वैकल्ये", gana="Bhvadi")
def root_1_969():
    """
    1.969 ट्वल वैकल्ये 
    """
    return "ट्वल"


@registry.register("1.970", root="ष्ठल", meaning="स्थाने", gana="Bhvadi")
def root_1_970():
    """
    1.970 ष्ठल स्थाने 
    """
    return "ष्ठल"


@registry.register("1.971", root="हल", meaning="विलेखने", gana="Bhvadi")
def root_1_971():
    """
    1.971 हल विलेखने 
    """
    return "हल"


@registry.register("1.972", root="णल", meaning="गन्धे", gana="Bhvadi")
def root_1_972():
    """
    1.972 णल गन्धे 
    """
    return "णल"


@registry.register("1.973", root="पल", meaning="गतौ", gana="Bhvadi")
def root_1_973():
    """
    1.973 पल गतौ 
    """
    return "पल"


@registry.register("1.974", root="बल", meaning="प्राणने धान्यावरोधे च धान्यावरोधने च", gana="Bhvadi")
def root_1_974():
    """
    1.974 बल प्राणने धान्यावरोधे च धान्यावरोधने च 
    """
    return "बल"


@registry.register("1.975", root="पुल", meaning="महत्त्वे", gana="Bhvadi")
def root_1_975():
    """
    1.975 पुल महत्त्वे 
    """
    return "पुल"


@registry.register("1.976", root="कुल", meaning="संस्त्याने बन्धुषु च", gana="Bhvadi")
def root_1_976():
    """
    1.976 कुल संस्त्याने बन्धुषु च 
    """
    return "कुल"


@registry.register("1.979", root="पतॢ", meaning="गतौ", gana="Bhvadi")
def root_1_979():
    """
    1.979 पतॢ गतौ 
    """
    return "पतॢ"


@registry.register("1.980", root="हुल", meaning="हिंसासंवरणयोश्च हिंसायां संवरणे च", gana="Bhvadi")
def root_1_980():
    """
    1.980 हुल हिंसासंवरणयोश्च हिंसायां संवरणे च 
    """
    return "हुल"


@registry.register("1.981", root="क्वथे", meaning="निष्पाके", gana="Bhvadi")
def root_1_981():
    """
    1.981 क्वथे निष्पाके 
    """
    return "क्वथे"


@registry.register("1.982", root="पथे", meaning="गतौ", gana="Bhvadi")
def root_1_982():
    """
    1.982 पथे गतौ 
    """
    return "पथे"


@registry.register("1.983", root="मथे", meaning="विलोडने", gana="Bhvadi")
def root_1_983():
    """
    1.983 मथे विलोडने 
    """
    return "मथे"


@registry.register("1.984", root="टुवम", meaning="उद्गिरणे", gana="Bhvadi")
def root_1_984():
    """
    1.984 टुवम उद्गिरणे 
    """
    return "टुवम"


@registry.register("1.985", root="भ्रमु", meaning="चलने", gana="Bhvadi")
def root_1_985():
    """
    1.985 भ्रमु चलने 
    """
    return "भ्रमु"


@registry.register("1.986", root="क्षर", meaning="सञ्चलने", gana="Bhvadi")
def root_1_986():
    """
    1.986 क्षर सञ्चलने 
    """
    return "क्षर"


@registry.register("1.987", root="क्षुर", meaning="सञ्चये", gana="Bhvadi")
def root_1_987():
    """
    1.987 क्षुर सञ्चये 
    """
    return "क्षुर"


@registry.register("1.988", root="षह", meaning="मर्षणे", gana="Bhvadi")
def root_1_988():
    """
    1.988 षह मर्षणे 
    """
    return "षह"


@registry.register("1.989", root="रमु", meaning="क्रीडायाम्", gana="Bhvadi")
def root_1_989():
    """
    1.989 रमु क्रीडायाम् 
    """
    return "रमु"


@registry.register("1.990", root="षदॢ", meaning="विशरणगत्यवसादनेषु", gana="Bhvadi")
def root_1_990():
    """
    1.990 षदॢ विशरणगत्यवसादनेषु 
    """
    return "षदॢ"


@registry.register("1.991", root="शदॢ", meaning="शातने", gana="Bhvadi")
def root_1_991():
    """
    1.991 शदॢ शातने 
    """
    return "शदॢ"


@registry.register("1.992", root="क्रुश", meaning="आह्वाने रोदने च", gana="Bhvadi")
def root_1_992():
    """
    1.992 क्रुश आह्वाने रोदने च 
    """
    return "क्रुश"


@registry.register("1.993", root="कुच", meaning="सम्पर्चनकौटिल्यप्रतिष्टम्भविलेखनेषु", gana="Bhvadi")
def root_1_993():
    """
    1.993 कुच सम्पर्चनकौटिल्यप्रतिष्टम्भविलेखनेषु 
    """
    return "कुच"


@registry.register("1.994", root="बुध", meaning="अवगमने", gana="Bhvadi")
def root_1_994():
    """
    1.994 बुध अवगमने 
    """
    return "बुध"


@registry.register("1.995", root="रुह", meaning="बीजजन्मनि प्रादुर्भावे च", gana="Bhvadi")
def root_1_995():
    """
    1.995 रुह बीजजन्मनि प्रादुर्भावे च 
    """
    return "रुह"


@registry.register("1.996", root="कस", meaning="गतौ", gana="Bhvadi")
def root_1_996():
    """
    1.996 कस गतौ 
    """
    return "कस"


@registry.register("1.997", root="हिक्क", meaning="अव्यक्ते शब्दे", gana="Bhvadi")
def root_1_997():
    """
    1.997 हिक्क अव्यक्ते शब्दे 
    """
    return "हिक्क"


@registry.register("1.998", root="अञ्चु", meaning="गतौ याचने च", gana="Bhvadi")
def root_1_998():
    """
    1.998 अञ्चु गतौ याचने च 
    """
    return "अञ्चु"


@registry.register("1.999", root="अचु", meaning="इत्येके", gana="Bhvadi")
def root_1_999():
    """
    1.999 अचु इत्येके 
    """
    return "अचु"


@registry.register("1.1000", root="अचि", meaning="इत्येपरे", gana="Bhvadi")
def root_1_1000():
    """
    1.1000 अचि इत्येपरे 
    """
    return "अचि"


@registry.register("1.1001", root="टुयाचृ", meaning="याच्ञायाम्", gana="Bhvadi")
def root_1_1001():
    """
    1.1001 टुयाचृ याच्ञायाम् 
    """
    return "टुयाचृ"


@registry.register("1.1002", root="रेटृ", meaning="परिभाषणे", gana="Bhvadi")
def root_1_1002():
    """
    1.1002 रेटृ परिभाषणे 
    """
    return "रेटृ"


@registry.register("1.1004", root="चदे", meaning="याचने च", gana="Bhvadi")
def root_1_1004():
    """
    1.1004 चदे याचने च 
    """
    return "चदे"


@registry.register("1.1005", root="प्रोथृ", meaning="पर्याप्तौ", gana="Bhvadi")
def root_1_1005():
    """
    1.1005 प्रोथृ पर्याप्तौ 
    """
    return "प्रोथृ"


@registry.register("1.1007", root="मेदृ", meaning="मेधाहिंसनयोः", gana="Bhvadi")
def root_1_1007():
    """
    1.1007 मेदृ मेधाहिंसनयोः 
    """
    return "मेदृ"


@registry.register("1.1009", root="मेथृ", meaning="इत्येके", gana="Bhvadi")
def root_1_1009():
    """
    1.1009 मेथृ इत्येके 
    """
    return "मेथृ"


@registry.register("1.1011", root="मेधृ", meaning="इत्यन्ये", gana="Bhvadi")
def root_1_1011():
    """
    1.1011 मेधृ इत्यन्ये 
    """
    return "मेधृ"


@registry.register("1.1013", root="णेदृ", meaning="कुत्सासन्निकर्षयोः", gana="Bhvadi")
def root_1_1013():
    """
    1.1013 णेदृ कुत्सासन्निकर्षयोः 
    """
    return "णेदृ"


@registry.register("1.1015", root="मृधु", meaning="उन्दने", gana="Bhvadi")
def root_1_1015():
    """
    1.1015 मृधु उन्दने 
    """
    return "मृधु"


@registry.register("1.1016", root="बुधिर्", meaning="बोधने", gana="Bhvadi")
def root_1_1016():
    """
    1.1016 बुधिर् बोधने 
    """
    return "बुधिर्"


@registry.register("1.1017", root="उबुन्दिर्", meaning="निशामने", gana="Bhvadi")
def root_1_1017():
    """
    1.1017 उबुन्दिर् निशामने 
    """
    return "उबुन्दिर्"


@registry.register("1.1018", root="वेणृ", meaning="गतिज्ञानचिन्तानिशामनवादित्रग्रहणेषु", gana="Bhvadi")
def root_1_1018():
    """
    1.1018 वेणृ गतिज्ञानचिन्तानिशामनवादित्रग्रहणेषु 
    """
    return "वेणृ"


@registry.register("1.1019", root="वेनृ", meaning="इत्येके", gana="Bhvadi")
def root_1_1019():
    """
    1.1019 वेनृ इत्येके 
    """
    return "वेनृ"


@registry.register("1.1020", root="खनु", meaning="अवदारणे", gana="Bhvadi")
def root_1_1020():
    """
    1.1020 खनु अवदारणे 
    """
    return "खनु"


@registry.register("1.1021", root="चीवृ", meaning="आदानसंवरणयोः", gana="Bhvadi")
def root_1_1021():
    """
    1.1021 चीवृ आदानसंवरणयोः 
    """
    return "चीवृ"


@registry.register("1.1022", root="चीबृ", meaning="इत्येके", gana="Bhvadi")
def root_1_1022():
    """
    1.1022 चीबृ इत्येके 
    """
    return "चीबृ"


@registry.register("1.1023", root="चायृ", meaning="पूजानिशामनयोः", gana="Bhvadi")
def root_1_1023():
    """
    1.1023 चायृ पूजानिशामनयोः 
    """
    return "चायृ"


@registry.register("1.1024", root="व्यय", meaning="गतौ", gana="Bhvadi")
def root_1_1024():
    """
    1.1024 व्यय गतौ 
    """
    return "व्यय"


@registry.register("1.1025", root="दाश‍ृ", meaning="दाने", gana="Bhvadi")
def root_1_1025():
    """
    1.1025 दाश‍ृ दाने 
    """
    return "दाश‍ृ"


@registry.register("1.1026", root="भेषृ", meaning="भये", gana="Bhvadi")
def root_1_1026():
    """
    1.1026 भेषृ भये 
    """
    return "भेषृ"


@registry.register("1.1028", root="भ्लेषृ", meaning="गतौ", gana="Bhvadi")
def root_1_1028():
    """
    1.1028 भ्लेषृ गतौ 
    """
    return "भ्लेषृ"


@registry.register("1.1029", root="अस", meaning="गतिदीप्त्यादानेषु", gana="Bhvadi")
def root_1_1029():
    """
    1.1029 अस गतिदीप्त्यादानेषु 
    """
    return "अस"


@registry.register("1.1030", root="अष", meaning="इत्येके", gana="Bhvadi")
def root_1_1030():
    """
    1.1030 अष इत्येके 
    """
    return "अष"


@registry.register("1.1031", root="अय", meaning="गतौ", gana="Bhvadi")
def root_1_1031():
    """
    1.1031 अय गतौ 
    """
    return "अय"


@registry.register("1.1032", root="स्पश", meaning="बाधनस्पर्शनयोः", gana="Bhvadi")
def root_1_1032():
    """
    1.1032 स्पश बाधनस्पर्शनयोः 
    """
    return "स्पश"


@registry.register("1.1033", root="लष", meaning="कान्तौ", gana="Bhvadi")
def root_1_1033():
    """
    1.1033 लष कान्तौ 
    """
    return "लष"


@registry.register("1.1034", root="चष", meaning="भक्षणे", gana="Bhvadi")
def root_1_1034():
    """
    1.1034 चष भक्षणे 
    """
    return "चष"


@registry.register("1.1035", root="छष", meaning="हिंसायाम्", gana="Bhvadi")
def root_1_1035():
    """
    1.1035 छष हिंसायाम् 
    """
    return "छष"


@registry.register("1.1036", root="झष", meaning="आदानसंवरणयोः", gana="Bhvadi")
def root_1_1036():
    """
    1.1036 झष आदानसंवरणयोः 
    """
    return "झष"


@registry.register("1.1038", root="भ्लक्ष", meaning="अदने", gana="Bhvadi")
def root_1_1038():
    """
    1.1038 भ्लक्ष अदने 
    """
    return "भ्लक्ष"


@registry.register("1.1039", root="भक्ष", meaning="इति मैत्रेयः", gana="Bhvadi")
def root_1_1039():
    """
    1.1039 भक्ष इति मैत्रेयः 
    """
    return "भक्ष"


@registry.register("1.1040", root="प्लक्ष", meaning="च", gana="Bhvadi")
def root_1_1040():
    """
    1.1040 प्लक्ष च 
    """
    return "प्लक्ष"


@registry.register("1.1041", root="दासृ", meaning="दाने", gana="Bhvadi")
def root_1_1041():
    """
    1.1041 दासृ दाने 
    """
    return "दासृ"


@registry.register("1.1042", root="माहृ", meaning="माने", gana="Bhvadi")
def root_1_1042():
    """
    1.1042 माहृ माने 
    """
    return "माहृ"


@registry.register("1.1043", root="गुहू", meaning="संवरणे", gana="Bhvadi")
def root_1_1043():
    """
    1.1043 गुहू संवरणे 
    """
    return "गुहू"


@registry.register("1.1044", root="श्रिञ्", meaning="सेवायाम्", gana="Bhvadi")
def root_1_1044():
    """
    1.1044 श्रिञ् सेवायाम् 
    """
    return "श्रिञ्"


@registry.register("1.1045", root="भृञ्", meaning="भरणे", gana="Bhvadi")
def root_1_1045():
    """
    1.1045 भृञ् भरणे 
    """
    return "भृञ्"


@registry.register("1.1046", root="हृञ्", meaning="हरणे", gana="Bhvadi")
def root_1_1046():
    """
    1.1046 हृञ् हरणे 
    """
    return "हृञ्"


@registry.register("1.1047", root="धृञ्", meaning="धारणे", gana="Bhvadi")
def root_1_1047():
    """
    1.1047 धृञ् धारणे 
    """
    return "धृञ्"


@registry.register("1.1048", root="कृञ्", meaning="करणे", gana="Bhvadi")
def root_1_1048():
    """
    1.1048 कृञ् करणे 
    """
    return "कृञ्"


@registry.register("1.1049", root="णीञ्", meaning="प्रापणे", gana="Bhvadi")
def root_1_1049():
    """
    1.1049 णीञ् प्रापणे 
    """
    return "णीञ्"


@registry.register("1.1050", root="धेट्", meaning="पाने", gana="Bhvadi")
def root_1_1050():
    """
    1.1050 धेट् पाने 
    """
    return "धेट्"


@registry.register("1.1052", root="म्लै", meaning="हर्षक्षये", gana="Bhvadi")
def root_1_1052():
    """
    1.1052 म्लै हर्षक्षये 
    """
    return "म्लै"


@registry.register("1.1053", root="द्यै", meaning="न्यक्करणे", gana="Bhvadi")
def root_1_1053():
    """
    1.1053 द्यै न्यक्करणे 
    """
    return "द्यै"


@registry.register("1.1054", root="द्रै", meaning="स्वप्ने", gana="Bhvadi")
def root_1_1054():
    """
    1.1054 द्रै स्वप्ने 
    """
    return "द्रै"


@registry.register("1.1055", root="ध्रै", meaning="तृप्तौ", gana="Bhvadi")
def root_1_1055():
    """
    1.1055 ध्रै तृप्तौ 
    """
    return "ध्रै"


@registry.register("1.1056", root="ध्यै", meaning="चिन्तायाम्", gana="Bhvadi")
def root_1_1056():
    """
    1.1056 ध्यै चिन्तायाम् 
    """
    return "ध्यै"


@registry.register("1.1057", root="रै", meaning="शब्दे", gana="Bhvadi")
def root_1_1057():
    """
    1.1057 रै शब्दे 
    """
    return "रै"


@registry.register("1.1059", root="ष्ट्यै", meaning="शब्दसङ्घातयोः", gana="Bhvadi")
def root_1_1059():
    """
    1.1059 ष्ट्यै शब्दसङ्घातयोः 
    """
    return "ष्ट्यै"


@registry.register("1.1060", root="खै", meaning="खदने", gana="Bhvadi")
def root_1_1060():
    """
    1.1060 खै खदने 
    """
    return "खै"


@registry.register("1.1063", root="षै", meaning="क्षये", gana="Bhvadi")
def root_1_1063():
    """
    1.1063 षै क्षये 
    """
    return "षै"


@registry.register("1.1065", root="गै", meaning="शब्दे", gana="Bhvadi")
def root_1_1065():
    """
    1.1065 गै शब्दे 
    """
    return "गै"


@registry.register("1.1067", root="श्रै", meaning="पाके", gana="Bhvadi")
def root_1_1067():
    """
    1.1067 श्रै पाके 
    """
    return "श्रै"


@registry.register("1.1068", root="स्रै", meaning="इति केषुचित्पाठः", gana="Bhvadi")
def root_1_1068():
    """
    1.1068 स्रै इति केषुचित्पाठः 
    """
    return "स्रै"


@registry.register("1.1070", root="ओवै", meaning="शोषणे", gana="Bhvadi")
def root_1_1070():
    """
    1.1070 ओवै शोषणे 
    """
    return "ओवै"


@registry.register("1.1072", root="ष्णै", meaning="वेष्टने", gana="Bhvadi")
def root_1_1072():
    """
    1.1072 ष्णै वेष्टने 
    """
    return "ष्णै"


@registry.register("1.1073", root="दैप्", meaning="शोधने", gana="Bhvadi")
def root_1_1073():
    """
    1.1073 दैप् शोधने 
    """
    return "दैप्"


@registry.register("1.1074", root="पा", meaning="पाने", gana="Bhvadi")
def root_1_1074():
    """
    1.1074 पा पाने 
    """
    return "पा"


@registry.register("1.1075", root="घ्रा", meaning="गन्धोपादाने घ्राणे", gana="Bhvadi")
def root_1_1075():
    """
    1.1075 घ्रा गन्धोपादाने घ्राणे 
    """
    return "घ्रा"


@registry.register("1.1076", root="ध्मा", meaning="शब्दाग्निसंयोगयोः", gana="Bhvadi")
def root_1_1076():
    """
    1.1076 ध्मा शब्दाग्निसंयोगयोः 
    """
    return "ध्मा"


@registry.register("1.1077", root="ष्ठा", meaning="गतिनिवृत्तौ", gana="Bhvadi")
def root_1_1077():
    """
    1.1077 ष्ठा गतिनिवृत्तौ 
    """
    return "ष्ठा"


@registry.register("1.1078", root="म्ना", meaning="अभ्यासे", gana="Bhvadi")
def root_1_1078():
    """
    1.1078 म्ना अभ्यासे 
    """
    return "म्ना"


@registry.register("1.1079", root="दाण्", meaning="दाने", gana="Bhvadi")
def root_1_1079():
    """
    1.1079 दाण् दाने 
    """
    return "दाण्"


@registry.register("1.1080", root="ह्वृ", meaning="कौटिल्ये", gana="Bhvadi")
def root_1_1080():
    """
    1.1080 ह्वृ कौटिल्ये 
    """
    return "ह्वृ"


@registry.register("1.1081", root="स्वृ", meaning="शब्दोपतापयोः", gana="Bhvadi")
def root_1_1081():
    """
    1.1081 स्वृ शब्दोपतापयोः 
    """
    return "स्वृ"


@registry.register("1.1082", root="स्मृ", meaning="चिन्तायाम्", gana="Bhvadi")
def root_1_1082():
    """
    1.1082 स्मृ चिन्तायाम् 
    """
    return "स्मृ"


@registry.register("1.1083", root="द्वृ", meaning="संवरणे वरणे", gana="Bhvadi")
def root_1_1083():
    """
    1.1083 द्वृ संवरणे वरणे 
    """
    return "द्वृ"


@registry.register("1.1084", root="ह्वृ", meaning="इत्येके", gana="Bhvadi")
def root_1_1084():
    """
    1.1084 ह्वृ इत्येके 
    """
    return "ह्वृ"


@registry.register("1.1085", root="सृ", meaning="गतौ", gana="Bhvadi")
def root_1_1085():
    """
    1.1085 सृ गतौ 
    """
    return "सृ"


@registry.register("1.1086", root="ऋ", meaning="गतिप्रापणयोः", gana="Bhvadi")
def root_1_1086():
    """
    1.1086 ऋ गतिप्रापणयोः 
    """
    return "ऋ"


@registry.register("1.1088", root="घृ", meaning="सेचने", gana="Bhvadi")
def root_1_1088():
    """
    1.1088 घृ सेचने 
    """
    return "घृ"


@registry.register("1.1089", root="ध्वृ", meaning="हूर्छने", gana="Bhvadi")
def root_1_1089():
    """
    1.1089 ध्वृ हूर्छने 
    """
    return "ध्वृ"


@registry.register("1.1090", root="स्रु", meaning="गतौ", gana="Bhvadi")
def root_1_1090():
    """
    1.1090 स्रु गतौ 
    """
    return "स्रु"


@registry.register("1.1091", root="षु", meaning="प्रसवसैश्वर्ययोः", gana="Bhvadi")
def root_1_1091():
    """
    1.1091 षु प्रसवसैश्वर्ययोः 
    """
    return "षु"


@registry.register("1.1092", root="श्रु", meaning="श्रवणे", gana="Bhvadi")
def root_1_1092():
    """
    1.1092 श्रु श्रवणे 
    """
    return "श्रु"


@registry.register("1.1093", root="ध्रु", meaning="स्थैर्ये", gana="Bhvadi")
def root_1_1093():
    """
    1.1093 ध्रु स्थैर्ये 
    """
    return "ध्रु"


@registry.register("1.1095", root="द्रु", meaning="गतौ", gana="Bhvadi")
def root_1_1095():
    """
    1.1095 द्रु गतौ 
    """
    return "द्रु"


@registry.register("1.1097", root="ज्रि", meaning="अभिभवे", gana="Bhvadi")
def root_1_1097():
    """
    1.1097 ज्रि अभिभवे 
    """
    return "ज्रि"


@registry.register("1.1098", root="जु", meaning="इति सौत्रो धातुः गत्यर्थः", gana="Bhvadi")
def root_1_1098():
    """
    1.1098 जु इति सौत्रो धातुः गत्यर्थः 
    """
    return "जु"


@registry.register("1.1099", root="ष्मिङ्", meaning="ईषद्धसने", gana="Bhvadi")
def root_1_1099():
    """
    1.1099 ष्मिङ् ईषद्धसने 
    """
    return "ष्मिङ्"


@registry.register("1.1100", root="गुङ्", meaning="अव्यक्ते शब्दे", gana="Bhvadi")
def root_1_1100():
    """
    1.1100 गुङ् अव्यक्ते शब्दे 
    """
    return "गुङ्"


@registry.register("1.1101", root="गाङ्", meaning="गतौ", gana="Bhvadi")
def root_1_1101():
    """
    1.1101 गाङ् गतौ 
    """
    return "गाङ्"


@registry.register("1.1107", root="ङुङ्", meaning="शब्दे", gana="Bhvadi")
def root_1_1107():
    """
    1.1107 ङुङ् शब्दे 
    """
    return "ङुङ्"


@registry.register("1.1112", root="प्लुङ्", meaning="गतौ", gana="Bhvadi")
def root_1_1112():
    """
    1.1112 प्लुङ् गतौ 
    """
    return "प्लुङ्"


@registry.register("1.1113", root="क्लुङ्", meaning="इत्येके", gana="Bhvadi")
def root_1_1113():
    """
    1.1113 क्लुङ् इत्येके 
    """
    return "क्लुङ्"


@registry.register("1.1114", root="रुङ्", meaning="गतिरोषणयोः", gana="Bhvadi")
def root_1_1114():
    """
    1.1114 रुङ् गतिरोषणयोः 
    """
    return "रुङ्"


@registry.register("1.1115", root="धृङ्", meaning="अवध्वंसने", gana="Bhvadi")
def root_1_1115():
    """
    1.1115 धृङ् अवध्वंसने 
    """
    return "धृङ्"


@registry.register("1.1116", root="मेङ्", meaning="प्रणिदाने", gana="Bhvadi")
def root_1_1116():
    """
    1.1116 मेङ् प्रणिदाने 
    """
    return "मेङ्"


@registry.register("1.1117", root="देङ्", meaning="रक्षणे", gana="Bhvadi")
def root_1_1117():
    """
    1.1117 देङ् रक्षणे 
    """
    return "देङ्"


@registry.register("1.1118", root="श्यैङ्", meaning="गतौ", gana="Bhvadi")
def root_1_1118():
    """
    1.1118 श्यैङ् गतौ 
    """
    return "श्यैङ्"


@registry.register("1.1119", root="प्यैङ्", meaning="वृद्धौ", gana="Bhvadi")
def root_1_1119():
    """
    1.1119 प्यैङ् वृद्धौ 
    """
    return "प्यैङ्"


@registry.register("1.1120", root="त्रैङ्", meaning="पालने", gana="Bhvadi")
def root_1_1120():
    """
    1.1120 त्रैङ् पालने 
    """
    return "त्रैङ्"


@registry.register("1.1121", root="पूङ्", meaning="पवने", gana="Bhvadi")
def root_1_1121():
    """
    1.1121 पूङ् पवने 
    """
    return "पूङ्"


@registry.register("1.1122", root="मूङ्", meaning="बन्धने", gana="Bhvadi")
def root_1_1122():
    """
    1.1122 मूङ् बन्धने 
    """
    return "मूङ्"


@registry.register("1.1123", root="डीङ्", meaning="विहायसा गतौ", gana="Bhvadi")
def root_1_1123():
    """
    1.1123 डीङ् विहायसा गतौ 
    """
    return "डीङ्"


@registry.register("1.1124", root="तृई", meaning="प्लवनतरणयोः", gana="Bhvadi")
def root_1_1124():
    """
    1.1124 तृई प्लवनतरणयोः 
    """
    return "तृई"


@registry.register("1.1125", root="गुप", meaning="गोपने", gana="Bhvadi")
def root_1_1125():
    """
    1.1125 गुप गोपने 
    """
    return "गुप"


@registry.register("1.1126", root="तिज", meaning="निशाने", gana="Bhvadi")
def root_1_1126():
    """
    1.1126 तिज निशाने 
    """
    return "तिज"


@registry.register("1.1127", root="मान", meaning="पूजायाम्", gana="Bhvadi")
def root_1_1127():
    """
    1.1127 मान पूजायाम् 
    """
    return "मान"


@registry.register("1.1128", root="बध", meaning="बन्धने", gana="Bhvadi")
def root_1_1128():
    """
    1.1128 बध बन्धने 
    """
    return "बध"


@registry.register("1.1129", root="रभ", meaning="राभस्ये", gana="Bhvadi")
def root_1_1129():
    """
    1.1129 रभ राभस्ये 
    """
    return "रभ"


@registry.register("1.1130", root="डुलभष्", meaning="प्राप्तौ", gana="Bhvadi")
def root_1_1130():
    """
    1.1130 डुलभष् प्राप्तौ 
    """
    return "डुलभष्"


@registry.register("1.1131", root="ष्वञ्ज", meaning="परिष्वङ्गे", gana="Bhvadi")
def root_1_1131():
    """
    1.1131 ष्वञ्ज परिष्वङ्गे 
    """
    return "ष्वञ्ज"


@registry.register("1.1132", root="हद", meaning="हद पुरीषोत्सर्गे", gana="Bhvadi")
def root_1_1132():
    """
    1.1132 हद हद पुरीषोत्सर्गे 
    """
    return "हद"


@registry.register("1.1133", root="ञिक्ष्विदा", meaning="अव्यक्ते शब्दे", gana="Bhvadi")
def root_1_1133():
    """
    1.1133 ञिक्ष्विदा अव्यक्ते शब्दे 
    """
    return "ञिक्ष्विदा"


@registry.register("1.1134", root="स्कन्दिर्", meaning="गतिशोषणयोः", gana="Bhvadi")
def root_1_1134():
    """
    1.1134 स्कन्दिर् गतिशोषणयोः 
    """
    return "स्कन्दिर्"


@registry.register("1.1135", root="यभ", meaning="मैथुने विपरीतमैथुने", gana="Bhvadi")
def root_1_1135():
    """
    1.1135 यभ मैथुने विपरीतमैथुने 
    """
    return "यभ"


@registry.register("1.1136", root="णम", meaning="प्रह्वत्वे शब्दे च", gana="Bhvadi")
def root_1_1136():
    """
    1.1136 णम प्रह्वत्वे शब्दे च 
    """
    return "णम"


@registry.register("1.1138", root="सृपॢ", meaning="गतौ", gana="Bhvadi")
def root_1_1138():
    """
    1.1138 सृपॢ गतौ 
    """
    return "सृपॢ"


@registry.register("1.1139", root="यम", meaning="उपरमे", gana="Bhvadi")
def root_1_1139():
    """
    1.1139 यम उपरमे 
    """
    return "यम"


@registry.register("1.1140", root="तप", meaning="सन्तापे", gana="Bhvadi")
def root_1_1140():
    """
    1.1140 तप सन्तापे 
    """
    return "तप"


@registry.register("1.1141", root="त्यज", meaning="हानौ", gana="Bhvadi")
def root_1_1141():
    """
    1.1141 त्यज हानौ 
    """
    return "त्यज"


@registry.register("1.1142", root="षञ्ज", meaning="सङ्गे", gana="Bhvadi")
def root_1_1142():
    """
    1.1142 षञ्ज सङ्गे 
    """
    return "षञ्ज"


@registry.register("1.1143", root="दृशिर्", meaning="प्रेक्षणे", gana="Bhvadi")
def root_1_1143():
    """
    1.1143 दृशिर् प्रेक्षणे 
    """
    return "दृशिर्"


@registry.register("1.1144", root="दंश", meaning="दशने", gana="Bhvadi")
def root_1_1144():
    """
    1.1144 दंश दशने 
    """
    return "दंश"


@registry.register("1.1145", root="कृष", meaning="विलेखने", gana="Bhvadi")
def root_1_1145():
    """
    1.1145 कृष विलेखने 
    """
    return "कृष"


@registry.register("1.1146", root="दह", meaning="भस्मीकरणे", gana="Bhvadi")
def root_1_1146():
    """
    1.1146 दह भस्मीकरणे 
    """
    return "दह"


@registry.register("1.1147", root="मिह", meaning="सेचने", gana="Bhvadi")
def root_1_1147():
    """
    1.1147 मिह सेचने 
    """
    return "मिह"


@registry.register("1.1148", root="कित", meaning="निवासे रोगापनयने च", gana="Bhvadi")
def root_1_1148():
    """
    1.1148 कित निवासे रोगापनयने च 
    """
    return "कित"


@registry.register("1.1149", root="दान", meaning="खण्डने अवखण्डने", gana="Bhvadi")
def root_1_1149():
    """
    1.1149 दान खण्डने अवखण्डने 
    """
    return "दान"


@registry.register("1.1150", root="शान", meaning="तेजने अवतेजने", gana="Bhvadi")
def root_1_1150():
    """
    1.1150 शान तेजने अवतेजने 
    """
    return "शान"


@registry.register("1.1151", root="डुपचष्", meaning="पाके", gana="Bhvadi")
def root_1_1151():
    """
    1.1151 डुपचष् पाके 
    """
    return "डुपचष्"


@registry.register("1.1152", root="षच", meaning="समवाये", gana="Bhvadi")
def root_1_1152():
    """
    1.1152 षच समवाये 
    """
    return "षच"


@registry.register("1.1153", root="भज", meaning="सेवायाम्", gana="Bhvadi")
def root_1_1153():
    """
    1.1153 भज सेवायाम् 
    """
    return "भज"


@registry.register("1.1154", root="रञ्ज", meaning="रागे", gana="Bhvadi")
def root_1_1154():
    """
    1.1154 रञ्ज रागे 
    """
    return "रञ्ज"


@registry.register("1.1155", root="शप", meaning="आक्रोशे", gana="Bhvadi")
def root_1_1155():
    """
    1.1155 शप आक्रोशे 
    """
    return "शप"


@registry.register("1.1156", root="त्विष", meaning="दीप्तौ", gana="Bhvadi")
def root_1_1156():
    """
    1.1156 त्विष दीप्तौ 
    """
    return "त्विष"


@registry.register("1.1157", root="यज", meaning="देवपूजासङ्गतिकरणदानेषु", gana="Bhvadi")
def root_1_1157():
    """
    1.1157 यज देवपूजासङ्गतिकरणदानेषु 
    """
    return "यज"


@registry.register("1.1158", root="डुवप", meaning="टुवप बीजसन्ताने", gana="Bhvadi")
def root_1_1158():
    """
    1.1158 डुवप टुवप बीजसन्ताने 
    """
    return "डुवप"


@registry.register("1.1159", root="वह", meaning="प्रापणे", gana="Bhvadi")
def root_1_1159():
    """
    1.1159 वह प्रापणे 
    """
    return "वह"


@registry.register("1.1160", root="वस", meaning="निवासे", gana="Bhvadi")
def root_1_1160():
    """
    1.1160 वस निवासे 
    """
    return "वस"


@registry.register("1.1161", root="वेञ्", meaning="तन्तुसन्ताने", gana="Bhvadi")
def root_1_1161():
    """
    1.1161 वेञ् तन्तुसन्ताने 
    """
    return "वेञ्"


@registry.register("1.1162", root="व्येञ्", meaning="संवरणे", gana="Bhvadi")
def root_1_1162():
    """
    1.1162 व्येञ् संवरणे 
    """
    return "व्येञ्"


@registry.register("1.1163", root="ह्वेञ्", meaning="स्पर्धायां शब्दे च", gana="Bhvadi")
def root_1_1163():
    """
    1.1163 ह्वेञ् स्पर्धायां शब्दे च 
    """
    return "ह्वेञ्"


@registry.register("1.1164", root="वद", meaning="व्यक्तायां वाचि", gana="Bhvadi")
def root_1_1164():
    """
    1.1164 वद व्यक्तायां वाचि 
    """
    return "वद"


@registry.register("1.1165", root="ट्वोश्वि", meaning="गतिवृद्ध्योः", gana="Bhvadi")
def root_1_1165():
    """
    1.1165 ट्वोश्वि गतिवृद्ध्योः 
    """
    return "ट्वोश्वि"
